# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: artifact/artifact/v1alpha/artifact_public_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from artifact.artifact.v1alpha import artifact_pb2 as artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2
from artifact.artifact.v1alpha import chunk_pb2 as artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2
from artifact.artifact.v1alpha import file_catalog_pb2 as artifact_dot_artifact_dot_v1alpha_dot_file__catalog__pb2
from artifact.artifact.v1alpha import object_pb2 as artifact_dot_artifact_dot_v1alpha_dot_object__pb2
from artifact.artifact.v1alpha import qa_pb2 as artifact_dot_artifact_dot_v1alpha_dot_qa__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7artifact/artifact/v1alpha/artifact_public_service.proto\x12\x19\x61rtifact.artifact.v1alpha\x1a(artifact/artifact/v1alpha/artifact.proto\x1a%artifact/artifact/v1alpha/chunk.proto\x1a,artifact/artifact/v1alpha/file_catalog.proto\x1a&artifact/artifact/v1alpha/object.proto\x1a\"artifact/artifact/v1alpha/qa.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/api/visibility.proto\x1a.protoc-gen-openapiv2/options/annotations.proto2\xd6!\n\x15\x41rtifactPublicService\x12\xac\x01\n\x08Liveness\x12*.artifact.artifact.v1alpha.LivenessRequest\x1a+.artifact.artifact.v1alpha.LivenessResponse\"G\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x31\x12\x13/v1alpha/__livenessZ\x1a\x12\x18/v1alpha/health/artifact\x12\xaf\x01\n\tReadiness\x12+.artifact.artifact.v1alpha.ReadinessRequest\x1a,.artifact.artifact.v1alpha.ReadinessResponse\"G\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x31\x12\x14/v1alpha/__readinessZ\x19\x12\x17/v1alpha/ready/artifact\x12\xb6\x01\n\rCreateCatalog\x12/.artifact.artifact.v1alpha.CreateCatalogRequest\x1a\x30.artifact.artifact.v1alpha.CreateCatalogResponse\"B\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02\x30\"+/v1alpha/namespaces/{namespace_id}/catalogs:\x01*\x12\xb0\x01\n\x0cListCatalogs\x12..artifact.artifact.v1alpha.ListCatalogsRequest\x1a/.artifact.artifact.v1alpha.ListCatalogsResponse\"?\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02-\x12+/v1alpha/namespaces/{namespace_id}/catalogs\x12\xc3\x01\n\rUpdateCatalog\x12/.artifact.artifact.v1alpha.UpdateCatalogRequest\x1a\x30.artifact.artifact.v1alpha.UpdateCatalogResponse\"O\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02=\x1a\x38/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}:\x01*\x12\xc0\x01\n\rDeleteCatalog\x12/.artifact.artifact.v1alpha.DeleteCatalogRequest\x1a\x30.artifact.artifact.v1alpha.DeleteCatalogResponse\"L\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02:*8/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}\x12\xd8\x01\n\x11UploadCatalogFile\x12\x33.artifact.artifact.v1alpha.UploadCatalogFileRequest\x1a\x34.artifact.artifact.v1alpha.UploadCatalogFileResponse\"X\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02\x46\">/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/files:\x04\x66ile\x12\xab\x01\n\x11\x44\x65leteCatalogFile\x12\x33.artifact.artifact.v1alpha.DeleteCatalogFileRequest\x1a\x34.artifact.artifact.v1alpha.DeleteCatalogFileResponse\"+\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02\x19*\x17/v1alpha/catalogs/files\x12\xe6\x02\n\x13ProcessCatalogFiles\x12\x35.artifact.artifact.v1alpha.ProcessCatalogFilesRequest\x1a\x36.artifact.artifact.v1alpha.ProcessCatalogFilesResponse\"\xdf\x01\x92\x41\xac\x01\n\x07\x43\x61talogr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02)\"$/v1alpha/catalogs/files/processAsync:\x01*\x12\xcf\x01\n\x10ListCatalogFiles\x12\x32.artifact.artifact.v1alpha.ListCatalogFilesRequest\x1a\x33.artifact.artifact.v1alpha.ListCatalogFilesResponse\"R\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02@\x12>/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/files\x12\xbe\x01\n\nListChunks\x12,.artifact.artifact.v1alpha.ListChunksRequest\x1a-.artifact.artifact.v1alpha.ListChunksResponse\"S\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02\x41\x12?/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/chunks\x12\xd8\x01\n\rGetSourceFile\x12/.artifact.artifact.v1alpha.GetSourceFileRequest\x1a\x30.artifact.artifact.v1alpha.GetSourceFileResponse\"d\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02R\x12P/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/files/{file_uid}/source\x12\xa0\x01\n\x0bUpdateChunk\x12-.artifact.artifact.v1alpha.UpdateChunkRequest\x1a..artifact.artifact.v1alpha.UpdateChunkResponse\"2\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02 \"\x1b/v1alpha/chunks/{chunk_uid}:\x01*\x12\x93\x03\n\x16SimilarityChunksSearch\x12\x38.artifact.artifact.v1alpha.SimilarityChunksSearchRequest\x1a\x39.artifact.artifact.v1alpha.SimilarityChunksSearchResponse\"\x83\x02\x92\x41\xac\x01\n\x07\x43\x61talogr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02M\"H/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/chunks/retrieve:\x01*\x12\xf8\x02\n\x11QuestionAnswering\x12\x33.artifact.artifact.v1alpha.QuestionAnsweringRequest\x1a\x34.artifact.artifact.v1alpha.QuestionAnsweringResponse\"\xf7\x01\x92\x41\xac\x01\n\x07\x43\x61talogr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02\x41\"</v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/ask:\x01*\x12\xc3\x01\n\x0eGetFileCatalog\x12\x30.artifact.artifact.v1alpha.GetFileCatalogRequest\x1a\x31.artifact.artifact.v1alpha.GetFileCatalogResponse\"L\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02:\x12\x38/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}\x12\xca\x01\n\x0fListCatalogRuns\x12\x31.artifact.artifact.v1alpha.ListCatalogRunsRequest\x1a\x32.artifact.artifact.v1alpha.ListCatalogRunsResponse\"P\x92\x41\t\n\x07\x43\x61talog\x82\xd3\xe4\x93\x02>\x12</v1beta/namespaces/{namespace_id}/catalogs/{catalog_id}/runs\x12\xca\x01\n\x12GetObjectUploadURL\x12\x34.artifact.artifact.v1alpha.GetObjectUploadURLRequest\x1a\x35.artifact.artifact.v1alpha.GetObjectUploadURLResponse\"G\x92\x41\x08\n\x06Object\x82\xd3\xe4\x93\x02\x36\x12\x34/v1alpha/namespaces/{namespace_id}/object-upload-url\x12\xd2\x01\n\x14GetObjectDownloadURL\x12\x36.artifact.artifact.v1alpha.GetObjectDownloadURLRequest\x1a\x37.artifact.artifact.v1alpha.GetObjectDownloadURLResponse\"I\x92\x41\x08\n\x06Object\x82\xd3\xe4\x93\x02\x38\x12\x36/v1alpha/namespaces/{namespace_id}/object-download-url\x1a\x1e\x92\x41\x1b\x12\x19Public Artifact endpointsB\x8e\x02\n\x1d\x63om.artifact.artifact.v1alphaB\x1a\x41rtifactPublicServiceProtoP\x01ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x19\x41rtifact.Artifact.V1alpha\xca\x02\x19\x41rtifact\\Artifact\\V1alpha\xe2\x02%Artifact\\Artifact\\V1alpha\\GPBMetadata\xea\x02\x1b\x41rtifact::Artifact::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'artifact.artifact.v1alpha.artifact_public_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.artifact.artifact.v1alphaB\032ArtifactPublicServiceProtoP\001ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\242\002\003AAX\252\002\031Artifact.Artifact.V1alpha\312\002\031Artifact\\Artifact\\V1alpha\342\002%Artifact\\Artifact\\V1alpha\\GPBMetadata\352\002\033Artifact::Artifact::V1alpha'
  _ARTIFACTPUBLICSERVICE._options = None
  _ARTIFACTPUBLICSERVICE._serialized_options = b'\222A\033\022\031Public Artifact endpoints'
  _ARTIFACTPUBLICSERVICE.methods_by_name['Liveness']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['Liveness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0021\022\023/v1alpha/__livenessZ\032\022\030/v1alpha/health/artifact'
  _ARTIFACTPUBLICSERVICE.methods_by_name['Readiness']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['Readiness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0021\022\024/v1alpha/__readinessZ\031\022\027/v1alpha/ready/artifact'
  _ARTIFACTPUBLICSERVICE.methods_by_name['CreateCatalog']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['CreateCatalog']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\0020\"+/v1alpha/namespaces/{namespace_id}/catalogs:\001*'
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListCatalogs']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListCatalogs']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002-\022+/v1alpha/namespaces/{namespace_id}/catalogs'
  _ARTIFACTPUBLICSERVICE.methods_by_name['UpdateCatalog']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['UpdateCatalog']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002=\0328/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}:\001*'
  _ARTIFACTPUBLICSERVICE.methods_by_name['DeleteCatalog']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['DeleteCatalog']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002:*8/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}'
  _ARTIFACTPUBLICSERVICE.methods_by_name['UploadCatalogFile']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['UploadCatalogFile']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002F\">/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/files:\004file'
  _ARTIFACTPUBLICSERVICE.methods_by_name['DeleteCatalogFile']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['DeleteCatalogFile']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002\031*\027/v1alpha/catalogs/files'
  _ARTIFACTPUBLICSERVICE.methods_by_name['ProcessCatalogFiles']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['ProcessCatalogFiles']._serialized_options = b'\222A\254\001\n\007Catalogr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002)\"$/v1alpha/catalogs/files/processAsync:\001*'
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListCatalogFiles']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListCatalogFiles']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002@\022>/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/files'
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListChunks']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListChunks']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002A\022?/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/chunks'
  _ARTIFACTPUBLICSERVICE.methods_by_name['GetSourceFile']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['GetSourceFile']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002R\022P/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/files/{file_uid}/source'
  _ARTIFACTPUBLICSERVICE.methods_by_name['UpdateChunk']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['UpdateChunk']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002 \"\033/v1alpha/chunks/{chunk_uid}:\001*'
  _ARTIFACTPUBLICSERVICE.methods_by_name['SimilarityChunksSearch']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['SimilarityChunksSearch']._serialized_options = b'\222A\254\001\n\007Catalogr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002M\"H/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/chunks/retrieve:\001*'
  _ARTIFACTPUBLICSERVICE.methods_by_name['QuestionAnswering']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['QuestionAnswering']._serialized_options = b'\222A\254\001\n\007Catalogr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002A\"</v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}/ask:\001*'
  _ARTIFACTPUBLICSERVICE.methods_by_name['GetFileCatalog']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['GetFileCatalog']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002:\0228/v1alpha/namespaces/{namespace_id}/catalogs/{catalog_id}'
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListCatalogRuns']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['ListCatalogRuns']._serialized_options = b'\222A\t\n\007Catalog\202\323\344\223\002>\022</v1beta/namespaces/{namespace_id}/catalogs/{catalog_id}/runs'
  _ARTIFACTPUBLICSERVICE.methods_by_name['GetObjectUploadURL']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['GetObjectUploadURL']._serialized_options = b'\222A\010\n\006Object\202\323\344\223\0026\0224/v1alpha/namespaces/{namespace_id}/object-upload-url'
  _ARTIFACTPUBLICSERVICE.methods_by_name['GetObjectDownloadURL']._options = None
  _ARTIFACTPUBLICSERVICE.methods_by_name['GetObjectDownloadURL']._serialized_options = b'\222A\010\n\006Object\202\323\344\223\0028\0226/v1alpha/namespaces/{namespace_id}/object-download-url'
  _globals['_ARTIFACTPUBLICSERVICE']._serialized_start=397
  _globals['_ARTIFACTPUBLICSERVICE']._serialized_end=4707
# @@protoc_insertion_point(module_scope)
