# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: common/task/v1alpha/task.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63ommon/task/v1alpha/task.proto\x12\x13\x63ommon.task.v1alpha*\xd3\x02\n\x04Task\x12\x14\n\x10TASK_UNSPECIFIED\x10\x00\x12\x17\n\x13TASK_CLASSIFICATION\x10\x01\x12\x12\n\x0eTASK_DETECTION\x10\x02\x12\x11\n\rTASK_KEYPOINT\x10\x03\x12\x0c\n\x08TASK_OCR\x10\x04\x12\x1e\n\x1aTASK_INSTANCE_SEGMENTATION\x10\x05\x12\x1e\n\x1aTASK_SEMANTIC_SEGMENTATION\x10\x06\x12\x16\n\x12TASK_TEXT_TO_IMAGE\x10\x07\x12\x17\n\x13TASK_IMAGE_TO_IMAGE\x10\x0b\x12\x12\n\x0eTASK_EMBEDDING\x10\x0c\x12\x1b\n\x17TASK_SPEECH_RECOGNITION\x10\r\x12\r\n\tTASK_CHAT\x10\x0e\x12\x13\n\x0fTASK_COMPLETION\x10\x0f\x12\x0f\n\x0bTASK_CUSTOM\x10\x10\"\x04\x08\x08\x10\x08\"\x04\x08\t\x10\t\"\x04\x08\n\x10\nB\xd5\x01\n\x17\x63om.common.task.v1alphaB\tTaskProtoP\x01ZAgithub.com/instill-ai/protogen-go/common/task/v1alpha;taskv1alpha\xa2\x02\x03\x43TX\xaa\x02\x13\x43ommon.Task.V1alpha\xca\x02\x13\x43ommon\\Task\\V1alpha\xe2\x02\x1f\x43ommon\\Task\\V1alpha\\GPBMetadata\xea\x02\x15\x43ommon::Task::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'common.task.v1alpha.task_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.common.task.v1alphaB\tTaskProtoP\001ZAgithub.com/instill-ai/protogen-go/common/task/v1alpha;taskv1alpha\242\002\003CTX\252\002\023Common.Task.V1alpha\312\002\023Common\\Task\\V1alpha\342\002\037Common\\Task\\V1alpha\\GPBMetadata\352\002\025Common::Task::V1alpha'
  _globals['_TASK']._serialized_start=56
  _globals['_TASK']._serialized_end=395
# @@protoc_insertion_point(module_scope)
