# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: artifact/artifact/v1alpha/file_catalog.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from artifact.artifact.v1alpha import artifact_pb2 as artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,artifact/artifact/v1alpha/file_catalog.proto\x12\x19\x61rtifact.artifact.v1alpha\x1a(artifact/artifact/v1alpha/artifact.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8d\x01\n\x15GetFileCatalogRequest\x12!\n\x0cnamespace_id\x18\x01 \x01(\tR\x0bnamespaceId\x12\x1d\n\ncatalog_id\x18\x02 \x01(\tR\tcatalogId\x12\x17\n\x07\x66ile_id\x18\x03 \x01(\tR\x06\x66ileId\x12\x19\n\x08\x66ile_uid\x18\x04 \x01(\tR\x07\x66ileUid\"\x95\x0b\n\x16GetFileCatalogResponse\x12#\n\roriginal_data\x18\x01 \x01(\tR\x0coriginalData\x12V\n\x08metadata\x18\x02 \x01(\x0b\x32:.artifact.artifact.v1alpha.GetFileCatalogResponse.MetadataR\x08metadata\x12J\n\x04text\x18\x03 \x01(\x0b\x32\x36.artifact.artifact.v1alpha.GetFileCatalogResponse.TextR\x04text\x12O\n\x06\x63hunks\x18\x04 \x03(\x0b\x32\x37.artifact.artifact.v1alpha.GetFileCatalogResponse.ChunkR\x06\x63hunks\x1a\xc1\x02\n\x08Metadata\x12\x19\n\x08\x66ile_uid\x18\x01 \x01(\tR\x07\x66ileUid\x12\x17\n\x07\x66ile_id\x18\x02 \x01(\tR\x06\x66ileId\x12@\n\tfile_type\x18\x03 \x01(\x0e\x32#.artifact.artifact.v1alpha.FileTypeR\x08\x66ileType\x12\x1b\n\tfile_size\x18\x04 \x01(\x03R\x08\x66ileSize\x12\x44\n\x10\x66ile_upload_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0e\x66ileUploadTime\x12\\\n\x13\x66ile_process_status\x18\x06 \x01(\x0e\x32,.artifact.artifact.v1alpha.FileProcessStatusR\x11\x66ileProcessStatus\x1a\xc3\x02\n\x04Text\x12!\n\x0cpipeline_ids\x18\x01 \x03(\tR\x0bpipelineIds\x12/\n\x13transformed_content\x18\x02 \x01(\tR\x12transformedContent\x12\x41\n\x1dtransformed_content_chunk_num\x18\x03 \x01(\x05R\x1atransformedContentChunkNum\x12\x41\n\x1dtransformed_content_token_num\x18\x04 \x01(\x05R\x1atransformedContentTokenNum\x12\x61\n\x1ftransformed_content_update_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x1ctransformedContentUpdateTime\x1a\xd6\x02\n\x05\x43hunk\x12\x10\n\x03uid\x18\x01 \x01(\tR\x03uid\x12O\n\x04type\x18\x02 \x01(\x0e\x32;.artifact.artifact.v1alpha.GetFileCatalogResponse.ChunkTypeR\x04type\x12\x1b\n\tstart_pos\x18\x03 \x01(\x05R\x08startPos\x12\x17\n\x07\x65nd_pos\x18\x04 \x01(\x05R\x06\x65ndPos\x12\x18\n\x07\x63ontent\x18\x05 \x01(\tR\x07\x63ontent\x12\x1d\n\ntokens_num\x18\x06 \x01(\x05R\ttokensNum\x12\x1c\n\tembedding\x18\x07 \x03(\x02R\tembedding\x12;\n\x0b\x63reate_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ncreateTime\x12 \n\x0bretrievable\x18\t \x01(\x08R\x0bretrievable\"~\n\tChunkType\x12\x1a\n\x16\x43HUNK_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x43HUNK_TYPE_TEXT\x10\x01\x12\x14\n\x10\x43HUNK_TYPE_IMAGE\x10\x02\x12\x14\n\x10\x43HUNK_TYPE_AUDIO\x10\x03\x12\x14\n\x10\x43HUNK_TYPE_VIDEO\x10\x04\x42\x84\x02\n\x1d\x63om.artifact.artifact.v1alphaB\x10\x46ileCatalogProtoP\x01ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x19\x41rtifact.Artifact.V1alpha\xca\x02\x19\x41rtifact\\Artifact\\V1alpha\xe2\x02%Artifact\\Artifact\\V1alpha\\GPBMetadata\xea\x02\x1b\x41rtifact::Artifact::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'artifact.artifact.v1alpha.file_catalog_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.artifact.artifact.v1alphaB\020FileCatalogProtoP\001ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\242\002\003AAX\252\002\031Artifact.Artifact.V1alpha\312\002\031Artifact\\Artifact\\V1alpha\342\002%Artifact\\Artifact\\V1alpha\\GPBMetadata\352\002\033Artifact::Artifact::V1alpha'
  _globals['_GETFILECATALOGREQUEST']._serialized_start=151
  _globals['_GETFILECATALOGREQUEST']._serialized_end=292
  _globals['_GETFILECATALOGRESPONSE']._serialized_start=295
  _globals['_GETFILECATALOGRESPONSE']._serialized_end=1724
  _globals['_GETFILECATALOGRESPONSE_METADATA']._serialized_start=604
  _globals['_GETFILECATALOGRESPONSE_METADATA']._serialized_end=925
  _globals['_GETFILECATALOGRESPONSE_TEXT']._serialized_start=928
  _globals['_GETFILECATALOGRESPONSE_TEXT']._serialized_end=1251
  _globals['_GETFILECATALOGRESPONSE_CHUNK']._serialized_start=1254
  _globals['_GETFILECATALOGRESPONSE_CHUNK']._serialized_end=1596
  _globals['_GETFILECATALOGRESPONSE_CHUNKTYPE']._serialized_start=1598
  _globals['_GETFILECATALOGRESPONSE_CHUNKTYPE']._serialized_end=1724
# @@protoc_insertion_point(module_scope)
