# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from core.metric.v1beta import metric_pb2 as core_dot_metric_dot_v1beta_dot_metric__pb2


class PipelineServiceStub(object):
    """Services related to pipeline trigger records
    Service for get pipeline information 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetPipelines = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/GetPipelines',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelinesRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelinesResponse.FromString,
                )
        self.ReportPipelineTrigger = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/ReportPipelineTrigger',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggerRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggerResponse.FromString,
                )
        self.ReportPipelineTriggers = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/ReportPipelineTriggers',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggersRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggersResponse.FromString,
                )
        self.GetPipelineTriggerRecords = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/GetPipelineTriggerRecords',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerRecordsRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerRecordsResponse.FromString,
                )
        self.GetBulkPipelineTriggerRecords = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/GetBulkPipelineTriggerRecords',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerRecordsRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerRecordsResponse.FromString,
                )
        self.GetCumulativePipelineTriggerRecords = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/GetCumulativePipelineTriggerRecords',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativePipelineTriggerRecordsRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativePipelineTriggerRecordsResponse.FromString,
                )
        self.GetBulkCumulativePipelineTriggerRecords = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/GetBulkCumulativePipelineTriggerRecords',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativePipelineTriggerRecordsRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativePipelineTriggerRecordsResponse.FromString,
                )
        self.GetPipelineTriggerSummary = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/GetPipelineTriggerSummary',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerSummaryRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerSummaryResponse.FromString,
                )
        self.GetBulkPipelineTriggerSummaries = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/GetBulkPipelineTriggerSummaries',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerSummariesRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerSummariesResponse.FromString,
                )
        self.GetPipelineTriggerPrice = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/GetPipelineTriggerPrice',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerPriceRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerPriceResponse.FromString,
                )
        self.GetBulkPipelineTriggerPrice = channel.unary_unary(
                '/core.metric.v1beta.PipelineService/GetBulkPipelineTriggerPrice',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerPriceRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerPriceResponse.FromString,
                )


class PipelineServiceServicer(object):
    """Services related to pipeline trigger records
    Service for get pipeline information 
    """

    def GetPipelines(self, request, context):
        """Get pipeline info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReportPipelineTrigger(self, request, context):
        """Services for reporting usages 

        For pipeline-backend clients to report a pipeline trigger record
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReportPipelineTriggers(self, request, context):
        """For pipeline-backend clients to report pipeline trigger records
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPipelineTriggerRecords(self, request, context):
        """Services for querying usages 

        Get pipeline trigger records
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBulkPipelineTriggerRecords(self, request, context):
        """Get pipeline trigger records in bulk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCumulativePipelineTriggerRecords(self, request, context):
        """Get cumulative pipeline trigger records
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBulkCumulativePipelineTriggerRecords(self, request, context):
        """Get cumulative pipeline trigger records in bulk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPipelineTriggerSummary(self, request, context):
        """Get pipeline trigger summary
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBulkPipelineTriggerSummaries(self, request, context):
        """Get pipeline trigger summary in bulk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPipelineTriggerPrice(self, request, context):
        """Services for querying prices 

        Get pipeline trigger price
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBulkPipelineTriggerPrice(self, request, context):
        """Get pipeline trigger price in bulk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PipelineServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetPipelines': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPipelines,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelinesRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelinesResponse.SerializeToString,
            ),
            'ReportPipelineTrigger': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportPipelineTrigger,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggerRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggerResponse.SerializeToString,
            ),
            'ReportPipelineTriggers': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportPipelineTriggers,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggersRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggersResponse.SerializeToString,
            ),
            'GetPipelineTriggerRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPipelineTriggerRecords,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerRecordsRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerRecordsResponse.SerializeToString,
            ),
            'GetBulkPipelineTriggerRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBulkPipelineTriggerRecords,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerRecordsRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerRecordsResponse.SerializeToString,
            ),
            'GetCumulativePipelineTriggerRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCumulativePipelineTriggerRecords,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativePipelineTriggerRecordsRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativePipelineTriggerRecordsResponse.SerializeToString,
            ),
            'GetBulkCumulativePipelineTriggerRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBulkCumulativePipelineTriggerRecords,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativePipelineTriggerRecordsRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativePipelineTriggerRecordsResponse.SerializeToString,
            ),
            'GetPipelineTriggerSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPipelineTriggerSummary,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerSummaryRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerSummaryResponse.SerializeToString,
            ),
            'GetBulkPipelineTriggerSummaries': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBulkPipelineTriggerSummaries,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerSummariesRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerSummariesResponse.SerializeToString,
            ),
            'GetPipelineTriggerPrice': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPipelineTriggerPrice,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerPriceRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerPriceResponse.SerializeToString,
            ),
            'GetBulkPipelineTriggerPrice': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBulkPipelineTriggerPrice,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerPriceRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerPriceResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'core.metric.v1beta.PipelineService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PipelineService(object):
    """Services related to pipeline trigger records
    Service for get pipeline information 
    """

    @staticmethod
    def GetPipelines(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/GetPipelines',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelinesRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelinesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReportPipelineTrigger(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/ReportPipelineTrigger',
            core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggerRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReportPipelineTriggers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/ReportPipelineTriggers',
            core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggersRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.ReportPipelineTriggersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPipelineTriggerRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/GetPipelineTriggerRecords',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerRecordsRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBulkPipelineTriggerRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/GetBulkPipelineTriggerRecords',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerRecordsRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCumulativePipelineTriggerRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/GetCumulativePipelineTriggerRecords',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativePipelineTriggerRecordsRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativePipelineTriggerRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBulkCumulativePipelineTriggerRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/GetBulkCumulativePipelineTriggerRecords',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativePipelineTriggerRecordsRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativePipelineTriggerRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPipelineTriggerSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/GetPipelineTriggerSummary',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerSummaryRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerSummaryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBulkPipelineTriggerSummaries(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/GetBulkPipelineTriggerSummaries',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerSummariesRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerSummariesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPipelineTriggerPrice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/GetPipelineTriggerPrice',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerPriceRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetPipelineTriggerPriceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBulkPipelineTriggerPrice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.PipelineService/GetBulkPipelineTriggerPrice',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerPriceRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkPipelineTriggerPriceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class ModelServiceStub(object):
    """Services related to model online records
    Service for get model information 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetModels = channel.unary_unary(
                '/core.metric.v1beta.ModelService/GetModels',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelsRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelsResponse.FromString,
                )
        self.ReportModelOnline = channel.unary_unary(
                '/core.metric.v1beta.ModelService/ReportModelOnline',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlineRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlineResponse.FromString,
                )
        self.ReportModelOnlines = channel.unary_unary(
                '/core.metric.v1beta.ModelService/ReportModelOnlines',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlinesRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlinesResponse.FromString,
                )
        self.GetModelOnlineRecords = channel.unary_unary(
                '/core.metric.v1beta.ModelService/GetModelOnlineRecords',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineRecordsRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineRecordsResponse.FromString,
                )
        self.GetBulkModelOnlineRecords = channel.unary_unary(
                '/core.metric.v1beta.ModelService/GetBulkModelOnlineRecords',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineRecordsRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineRecordsResponse.FromString,
                )
        self.GetCumulativeModelOnlineRecords = channel.unary_unary(
                '/core.metric.v1beta.ModelService/GetCumulativeModelOnlineRecords',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativeModelOnlineRecordsRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativeModelOnlineRecordsResponse.FromString,
                )
        self.GetBulkCumulativeModelOnlineRecords = channel.unary_unary(
                '/core.metric.v1beta.ModelService/GetBulkCumulativeModelOnlineRecords',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativeModelOnlineRecordsRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativeModelOnlineRecordsResponse.FromString,
                )
        self.GetModelOnlineSummary = channel.unary_unary(
                '/core.metric.v1beta.ModelService/GetModelOnlineSummary',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineSummaryRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineSummaryResponse.FromString,
                )
        self.GetBulkModelOnlineSummary = channel.unary_unary(
                '/core.metric.v1beta.ModelService/GetBulkModelOnlineSummary',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineSummaryRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineSummaryResponse.FromString,
                )
        self.GetModelOnlinePrice = channel.unary_unary(
                '/core.metric.v1beta.ModelService/GetModelOnlinePrice',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlinePriceRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlinePriceResponse.FromString,
                )
        self.GetBulkModelOnlinePrice = channel.unary_unary(
                '/core.metric.v1beta.ModelService/GetBulkModelOnlinePrice',
                request_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlinePriceRequest.SerializeToString,
                response_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlinePriceResponse.FromString,
                )


class ModelServiceServicer(object):
    """Services related to model online records
    Service for get model information 
    """

    def GetModels(self, request, context):
        """Get Model info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReportModelOnline(self, request, context):
        """Services for reporting usages 

        For model-backend clients to report a model online record
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReportModelOnlines(self, request, context):
        """For model-backend clients to report moel online records
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelOnlineRecords(self, request, context):
        """Services for querying usages 

        Get model online records
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBulkModelOnlineRecords(self, request, context):
        """Get model online records in bulk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCumulativeModelOnlineRecords(self, request, context):
        """Get cumulative model online records
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBulkCumulativeModelOnlineRecords(self, request, context):
        """Get cumulative model online records in bulk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelOnlineSummary(self, request, context):
        """Get model online summary
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBulkModelOnlineSummary(self, request, context):
        """Get model online summary in bulk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelOnlinePrice(self, request, context):
        """Services for querying prices 

        Get model online price
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBulkModelOnlinePrice(self, request, context):
        """Get model online price in bulk
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ModelServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetModels': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModels,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelsRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelsResponse.SerializeToString,
            ),
            'ReportModelOnline': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportModelOnline,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlineRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlineResponse.SerializeToString,
            ),
            'ReportModelOnlines': grpc.unary_unary_rpc_method_handler(
                    servicer.ReportModelOnlines,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlinesRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlinesResponse.SerializeToString,
            ),
            'GetModelOnlineRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelOnlineRecords,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineRecordsRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineRecordsResponse.SerializeToString,
            ),
            'GetBulkModelOnlineRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBulkModelOnlineRecords,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineRecordsRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineRecordsResponse.SerializeToString,
            ),
            'GetCumulativeModelOnlineRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCumulativeModelOnlineRecords,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativeModelOnlineRecordsRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativeModelOnlineRecordsResponse.SerializeToString,
            ),
            'GetBulkCumulativeModelOnlineRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBulkCumulativeModelOnlineRecords,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativeModelOnlineRecordsRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativeModelOnlineRecordsResponse.SerializeToString,
            ),
            'GetModelOnlineSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelOnlineSummary,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineSummaryRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineSummaryResponse.SerializeToString,
            ),
            'GetBulkModelOnlineSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBulkModelOnlineSummary,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineSummaryRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineSummaryResponse.SerializeToString,
            ),
            'GetModelOnlinePrice': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelOnlinePrice,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlinePriceRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlinePriceResponse.SerializeToString,
            ),
            'GetBulkModelOnlinePrice': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBulkModelOnlinePrice,
                    request_deserializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlinePriceRequest.FromString,
                    response_serializer=core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlinePriceResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'core.metric.v1beta.ModelService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ModelService(object):
    """Services related to model online records
    Service for get model information 
    """

    @staticmethod
    def GetModels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/GetModels',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelsRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReportModelOnline(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/ReportModelOnline',
            core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlineRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlineResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReportModelOnlines(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/ReportModelOnlines',
            core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlinesRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.ReportModelOnlinesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelOnlineRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/GetModelOnlineRecords',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineRecordsRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBulkModelOnlineRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/GetBulkModelOnlineRecords',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineRecordsRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCumulativeModelOnlineRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/GetCumulativeModelOnlineRecords',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativeModelOnlineRecordsRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetCumulativeModelOnlineRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBulkCumulativeModelOnlineRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/GetBulkCumulativeModelOnlineRecords',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativeModelOnlineRecordsRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkCumulativeModelOnlineRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelOnlineSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/GetModelOnlineSummary',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineSummaryRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlineSummaryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBulkModelOnlineSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/GetBulkModelOnlineSummary',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineSummaryRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlineSummaryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelOnlinePrice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/GetModelOnlinePrice',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlinePriceRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetModelOnlinePriceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBulkModelOnlinePrice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.metric.v1beta.ModelService/GetBulkModelOnlinePrice',
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlinePriceRequest.SerializeToString,
            core_dot_metric_dot_v1beta_dot_metric__pb2.GetBulkModelOnlinePriceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
