# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from model.model.v1alpha import model_pb2 as model_dot_model_dot_v1alpha_dot_model__pb2


class ModelPrivateServiceStub(object):
    """Model service responds to internal access
    ========== Private API ==========
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListModelsAdmin = channel.unary_unary(
                '/model.model.v1alpha.ModelPrivateService/ListModelsAdmin',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsAdminRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsAdminResponse.FromString,
                )
        self.LookUpModelAdmin = channel.unary_unary(
                '/model.model.v1alpha.ModelPrivateService/LookUpModelAdmin',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelAdminRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelAdminResponse.FromString,
                )
        self.DeployNamespaceModelAdmin = channel.unary_unary(
                '/model.model.v1alpha.ModelPrivateService/DeployNamespaceModelAdmin',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployNamespaceModelAdminRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployNamespaceModelAdminResponse.FromString,
                )
        self.DeployUserModelAdmin = channel.unary_unary(
                '/model.model.v1alpha.ModelPrivateService/DeployUserModelAdmin',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelAdminRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelAdminResponse.FromString,
                )
        self.DeployOrganizationModelAdmin = channel.unary_unary(
                '/model.model.v1alpha.ModelPrivateService/DeployOrganizationModelAdmin',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelAdminRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelAdminResponse.FromString,
                )
        self.UndeployUserModelAdmin = channel.unary_unary(
                '/model.model.v1alpha.ModelPrivateService/UndeployUserModelAdmin',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelAdminRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelAdminResponse.FromString,
                )
        self.UndeployNamespaceModelAdmin = channel.unary_unary(
                '/model.model.v1alpha.ModelPrivateService/UndeployNamespaceModelAdmin',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployNamespaceModelAdminRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployNamespaceModelAdminResponse.FromString,
                )
        self.UndeployOrganizationModelAdmin = channel.unary_unary(
                '/model.model.v1alpha.ModelPrivateService/UndeployOrganizationModelAdmin',
                request_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelAdminRequest.SerializeToString,
                response_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelAdminResponse.FromString,
                )


class ModelPrivateServiceServicer(object):
    """Model service responds to internal access
    ========== Private API ==========
    """

    def ListModelsAdmin(self, request, context):
        """ListModelsAdmin method receives a ListModelsAdminRequest message and
        returns a ListModelsAdminResponse
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LookUpModelAdmin(self, request, context):
        """LookUpModelAdmin method receives a LookUpModelAdminRequest message and
        returns a LookUpModelAdminResponse
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployNamespaceModelAdmin(self, request, context):
        """DeployNamespaceModelAdmin deploy a model to online state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployUserModelAdmin(self, request, context):
        """DeployUserModelAdmin deploy a model to online state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployOrganizationModelAdmin(self, request, context):
        """DeployOrganizationModelAdmin deploy a model to online state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UndeployUserModelAdmin(self, request, context):
        """UndeployUserModelAdmin undeploy a model to offline state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UndeployNamespaceModelAdmin(self, request, context):
        """UndeployNamespaceModelAdmin undeploy a model to offline state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UndeployOrganizationModelAdmin(self, request, context):
        """UndeployOrganizationModelAdmin undeploy a model to offline state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ModelPrivateServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListModelsAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModelsAdmin,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsAdminRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsAdminResponse.SerializeToString,
            ),
            'LookUpModelAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.LookUpModelAdmin,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelAdminRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelAdminResponse.SerializeToString,
            ),
            'DeployNamespaceModelAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployNamespaceModelAdmin,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployNamespaceModelAdminRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployNamespaceModelAdminResponse.SerializeToString,
            ),
            'DeployUserModelAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployUserModelAdmin,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelAdminRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelAdminResponse.SerializeToString,
            ),
            'DeployOrganizationModelAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployOrganizationModelAdmin,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelAdminRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelAdminResponse.SerializeToString,
            ),
            'UndeployUserModelAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.UndeployUserModelAdmin,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelAdminRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelAdminResponse.SerializeToString,
            ),
            'UndeployNamespaceModelAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.UndeployNamespaceModelAdmin,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployNamespaceModelAdminRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployNamespaceModelAdminResponse.SerializeToString,
            ),
            'UndeployOrganizationModelAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.UndeployOrganizationModelAdmin,
                    request_deserializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelAdminRequest.FromString,
                    response_serializer=model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelAdminResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'model.model.v1alpha.ModelPrivateService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ModelPrivateService(object):
    """Model service responds to internal access
    ========== Private API ==========
    """

    @staticmethod
    def ListModelsAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPrivateService/ListModelsAdmin',
            model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsAdminRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.ListModelsAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LookUpModelAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPrivateService/LookUpModelAdmin',
            model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelAdminRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.LookUpModelAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployNamespaceModelAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPrivateService/DeployNamespaceModelAdmin',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeployNamespaceModelAdminRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeployNamespaceModelAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployUserModelAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPrivateService/DeployUserModelAdmin',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelAdminRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeployUserModelAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployOrganizationModelAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPrivateService/DeployOrganizationModelAdmin',
            model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelAdminRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.DeployOrganizationModelAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UndeployUserModelAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPrivateService/UndeployUserModelAdmin',
            model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelAdminRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UndeployUserModelAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UndeployNamespaceModelAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPrivateService/UndeployNamespaceModelAdmin',
            model_dot_model_dot_v1alpha_dot_model__pb2.UndeployNamespaceModelAdminRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UndeployNamespaceModelAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UndeployOrganizationModelAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/model.model.v1alpha.ModelPrivateService/UndeployOrganizationModelAdmin',
            model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelAdminRequest.SerializeToString,
            model_dot_model_dot_v1alpha_dot_model__pb2.UndeployOrganizationModelAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
