"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class HealthCheckRequest(google.protobuf.message.Message):
    """HealthCheckRequest represents a request to health check a service"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_FIELD_NUMBER: builtins.int
    service: builtins.str
    """Service name to check for its readiness status"""
    def __init__(
        self,
        *,
        service: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_service", b"_service", "service", b"service"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_service", b"_service", "service", b"service"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_service", b"_service"]) -> typing_extensions.Literal["service"] | None: ...

global___HealthCheckRequest = HealthCheckRequest

@typing_extensions.final
class HealthCheckResponse(google.protobuf.message.Message):
    """HealthCheckResponse represents a response for a service heath status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ServingStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ServingStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[HealthCheckResponse._ServingStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SERVING_STATUS_UNSPECIFIED: HealthCheckResponse._ServingStatus.ValueType  # 0
        """Serving status: UNSPECIFIED"""
        SERVING_STATUS_SERVING: HealthCheckResponse._ServingStatus.ValueType  # 1
        """Serving status: SERVING"""
        SERVING_STATUS_NOT_SERVING: HealthCheckResponse._ServingStatus.ValueType  # 2
        """Serving status: NOT SERVING"""

    class ServingStatus(_ServingStatus, metaclass=_ServingStatusEnumTypeWrapper):
        """ServingStatus enumerates the status of a queried service"""

    SERVING_STATUS_UNSPECIFIED: HealthCheckResponse.ServingStatus.ValueType  # 0
    """Serving status: UNSPECIFIED"""
    SERVING_STATUS_SERVING: HealthCheckResponse.ServingStatus.ValueType  # 1
    """Serving status: SERVING"""
    SERVING_STATUS_NOT_SERVING: HealthCheckResponse.ServingStatus.ValueType  # 2
    """Serving status: NOT SERVING"""

    STATUS_FIELD_NUMBER: builtins.int
    status: global___HealthCheckResponse.ServingStatus.ValueType
    """Status is the instance of the enum type ServingStatus"""
    def __init__(
        self,
        *,
        status: global___HealthCheckResponse.ServingStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___HealthCheckResponse = HealthCheckResponse
