"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class BoundingBox(google.protobuf.message.Message):
    """BoundingBox represents a frame in an image that can be drawn when detecting
    patterns in objects.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOP_FIELD_NUMBER: builtins.int
    LEFT_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    top: builtins.float
    """Top Y-axis."""
    left: builtins.float
    """Left X-axis."""
    width: builtins.float
    """Width."""
    height: builtins.float
    """Height."""
    def __init__(
        self,
        *,
        top: builtins.float = ...,
        left: builtins.float = ...,
        width: builtins.float = ...,
        height: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height", "left", b"left", "top", b"top", "width", b"width"]) -> None: ...

global___BoundingBox = BoundingBox

@typing_extensions.final
class PromptImage(google.protobuf.message.Message):
    """PromptImage is an image input for model inference."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMPT_IMAGE_URL_FIELD_NUMBER: builtins.int
    PROMPT_IMAGE_BASE64_FIELD_NUMBER: builtins.int
    prompt_image_url: builtins.str
    """Image URL."""
    prompt_image_base64: builtins.str
    """Base64-encoded image."""
    def __init__(
        self,
        *,
        prompt_image_url: builtins.str = ...,
        prompt_image_base64: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["prompt_image_base64", b"prompt_image_base64", "prompt_image_url", b"prompt_image_url", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["prompt_image_base64", b"prompt_image_base64", "prompt_image_url", b"prompt_image_url", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["prompt_image_url", "prompt_image_base64"] | None: ...

global___PromptImage = PromptImage

@typing_extensions.final
class ImageContent(google.protobuf.message.Message):
    """ImageContent holds an image with some details in plain text."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_URL_FIELD_NUMBER: builtins.int
    DETAIL_FIELD_NUMBER: builtins.int
    @property
    def image_url(self) -> global___PromptImage:
        """Image as URL or base64 code.

        NOTE: the `image_url` name comes from a convention from OpenAI, it doesn't
        determine the format of the image.
        """
    detail: builtins.str
    """Additional information."""
    def __init__(
        self,
        *,
        image_url: global___PromptImage | None = ...,
        detail: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_detail", b"_detail", "detail", b"detail", "image_url", b"image_url"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_detail", b"_detail", "detail", b"detail", "image_url", b"image_url"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_detail", b"_detail"]) -> typing_extensions.Literal["detail"] | None: ...

global___ImageContent = ImageContent

@typing_extensions.final
class MessageContent(google.protobuf.message.Message):
    """MessageContent is a message in a chat history message, used in text
    generation models.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    IMAGE_URL_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    type: builtins.str
    """Content type."""
    @property
    def image_url(self) -> global___ImageContent:
        """Image content.

        NOTE: the `image_url` name comes from a convention from OpenAI, it doesn't
        determine the format of the image.
        """
    text: builtins.str
    """Text content."""
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        image_url: global___ImageContent | None = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content", b"content", "image_url", b"image_url", "text", b"text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "image_url", b"image_url", "text", b"text", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["content", b"content"]) -> typing_extensions.Literal["image_url", "text"] | None: ...

global___MessageContent = MessageContent

@typing_extensions.final
class Message(google.protobuf.message.Message):
    """Message is used in chat history in text generation models."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    role: builtins.str
    """The Role of a message, e.g. `system`, `user`, etc. Defines the way the model answers questions."""
    @property
    def content(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MessageContent]:
        """Message content."""
    def __init__(
        self,
        *,
        role: builtins.str = ...,
        content: collections.abc.Iterable[global___MessageContent] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "role", b"role"]) -> None: ...

global___Message = Message

@typing_extensions.final
class Permission(google.protobuf.message.Message):
    """Permission defines how a pipeline can be used."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAN_EDIT_FIELD_NUMBER: builtins.int
    CAN_TRIGGER_FIELD_NUMBER: builtins.int
    can_edit: builtins.bool
    """Defines whether the pipeline can be modified."""
    can_trigger: builtins.bool
    """Defines whether the pipeline can be executed."""
    def __init__(
        self,
        *,
        can_edit: builtins.bool = ...,
        can_trigger: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["can_edit", b"can_edit", "can_trigger", b"can_trigger"]) -> None: ...

global___Permission = Permission
