# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: app/app/v1alpha/app_public_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from app.app.v1alpha import app_pb2 as app_dot_app_dot_v1alpha_dot_app__pb2
from app.app.v1alpha import conversation_pb2 as app_dot_app_dot_v1alpha_dot_conversation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(app/app/v1alpha/app_public_service.proto\x12\x0f\x61pp.app.v1alpha\x1a\x19\x61pp/app/v1alpha/app.proto\x1a\"app/app/v1alpha/conversation.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/api/visibility.proto\x1a.protoc-gen-openapiv2/options/annotations.proto2\xd0\x19\n\x10\x41ppPublicService\x12\x93\x01\n\x08Liveness\x12 .app.app.v1alpha.LivenessRequest\x1a!.app.app.v1alpha.LivenessResponse\"B\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02,\x12\x13/v1alpha/__livenessZ\x15\x12\x13/v1alpha/health/app\x12\x96\x01\n\tReadiness\x12!.app.app.v1alpha.ReadinessRequest\x1a\".app.app.v1alpha.ReadinessResponse\"B\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02,\x12\x14/v1alpha/__readinessZ\x14\x12\x12/v1alpha/ready/app\x12\x8e\x01\n\tCreateApp\x12!.app.app.v1alpha.CreateAppRequest\x1a\".app.app.v1alpha.CreateAppResponse\":\x92\x41\x05\n\x03\x41pp\x82\xd3\xe4\x93\x02,\"\'/v1alpha/namespaces/{namespace_id}/apps:\x01*\x12\x88\x01\n\x08ListApps\x12 .app.app.v1alpha.ListAppsRequest\x1a!.app.app.v1alpha.ListAppsResponse\"7\x92\x41\x05\n\x03\x41pp\x82\xd3\xe4\x93\x02)\x12\'/v1alpha/namespaces/{namespace_id}/apps\x12\x97\x01\n\tUpdateApp\x12!.app.app.v1alpha.UpdateAppRequest\x1a\".app.app.v1alpha.UpdateAppResponse\"C\x92\x41\x05\n\x03\x41pp\x82\xd3\xe4\x93\x02\x35\x1a\x30/v1alpha/namespaces/{namespace_id}/apps/{app_id}:\x01*\x12\x94\x01\n\tDeleteApp\x12!.app.app.v1alpha.DeleteAppRequest\x1a\".app.app.v1alpha.DeleteAppResponse\"@\x92\x41\x05\n\x03\x41pp\x82\xd3\xe4\x93\x02\x32*0/v1alpha/namespaces/{namespace_id}/apps/{app_id}\x12\xc9\x01\n\x12\x43reateConversation\x12*.app.app.v1alpha.CreateConversationRequest\x1a+.app.app.v1alpha.CreateConversationResponse\"Z\x92\x41\x0e\n\x0c\x43onversation\x82\xd3\xe4\x93\x02\x43\">/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations:\x01*\x12\xc3\x01\n\x11ListConversations\x12).app.app.v1alpha.ListConversationsRequest\x1a*.app.app.v1alpha.ListConversationsResponse\"W\x92\x41\x0e\n\x0c\x43onversation\x82\xd3\xe4\x93\x02@\x12>/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations\x12\xdb\x01\n\x12UpdateConversation\x12*.app.app.v1alpha.UpdateConversationRequest\x1a+.app.app.v1alpha.UpdateConversationResponse\"l\x92\x41\x0e\n\x0c\x43onversation\x82\xd3\xe4\x93\x02U\x1aP/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}:\x01*\x12\xd8\x01\n\x12\x44\x65leteConversation\x12*.app.app.v1alpha.DeleteConversationRequest\x1a+.app.app.v1alpha.DeleteConversationResponse\"i\x92\x41\x0e\n\x0c\x43onversation\x82\xd3\xe4\x93\x02R*P/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}\x12\xd0\x01\n\rCreateMessage\x12%.app.app.v1alpha.CreateMessageRequest\x1a&.app.app.v1alpha.CreateMessageResponse\"p\x92\x41\t\n\x07Message\x82\xd3\xe4\x93\x02^\"Y/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}/messages:\x01*\x12\xca\x01\n\x0cListMessages\x12$.app.app.v1alpha.ListMessagesRequest\x1a%.app.app.v1alpha.ListMessagesResponse\"m\x92\x41\t\n\x07Message\x82\xd3\xe4\x93\x02[\x12Y/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}/messages\x12\xde\x01\n\rUpdateMessage\x12%.app.app.v1alpha.UpdateMessageRequest\x1a&.app.app.v1alpha.UpdateMessageResponse\"~\x92\x41\t\n\x07Message\x82\xd3\xe4\x93\x02l\x1ag/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}/messages/{message_uid}:\x01*\x12\xdb\x01\n\rDeleteMessage\x12%.app.app.v1alpha.DeleteMessageRequest\x1a&.app.app.v1alpha.DeleteMessageResponse\"{\x92\x41\t\n\x07Message\x82\xd3\xe4\x93\x02i*g/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}/messages/{message_uid}\x12\xf0\x01\n\x19GetPlaygroundConversation\x12\x31.app.app.v1alpha.GetPlaygroundConversationRequest\x1a\x32.app.app.v1alpha.GetPlaygroundConversationResponse\"l\x92\x41\x0c\n\nPlayground\x82\xd3\xe4\x93\x02W\x12U/v1alpha/namespaces/{namespace_id}/apps/{app_id}/ai_assistant_playground/conversation\x12\xf7\x01\n\x1dRestartPlaygroundConversation\x12\x35.app.app.v1alpha.RestartPlaygroundConversationRequest\x1a\x36.app.app.v1alpha.RestartPlaygroundConversationResponse\"g\x92\x41\x0c\n\nPlayground\x82\xd3\xe4\x93\x02R\"P/v1alpha/namespaces/{namespace_id}/apps/{app_id}/ai_assistant_playground/restart\x12\x8d\x01\n\x04\x43hat\x12\x1c.app.app.v1alpha.ChatRequest\x1a\x1d.app.app.v1alpha.ChatResponse\"H\x92\x41\x05\n\x03\x41pp\x82\xd3\xe4\x93\x02:\"5/v1alpha/namespaces/{namespace_id}/apps/{app_id}/chat:\x01*\x1a\x19\x92\x41\x16\x12\x14Public App endpointsB\xc8\x01\n\x13\x63om.app.app.v1alphaB\x15\x41ppPublicServiceProtoP\x01Z<github.com/instill-ai/protogen-go/app/app/v1alpha;appv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x0f\x41pp.App.V1alpha\xca\x02\x0f\x41pp\\App\\V1alpha\xe2\x02\x1b\x41pp\\App\\V1alpha\\GPBMetadata\xea\x02\x11\x41pp::App::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'app.app.v1alpha.app_public_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023com.app.app.v1alphaB\025AppPublicServiceProtoP\001Z<github.com/instill-ai/protogen-go/app/app/v1alpha;appv1alpha\242\002\003AAX\252\002\017App.App.V1alpha\312\002\017App\\App\\V1alpha\342\002\033App\\App\\V1alpha\\GPBMetadata\352\002\021App::App::V1alpha'
  _APPPUBLICSERVICE._options = None
  _APPPUBLICSERVICE._serialized_options = b'\222A\026\022\024Public App endpoints'
  _APPPUBLICSERVICE.methods_by_name['Liveness']._options = None
  _APPPUBLICSERVICE.methods_by_name['Liveness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002,\022\023/v1alpha/__livenessZ\025\022\023/v1alpha/health/app'
  _APPPUBLICSERVICE.methods_by_name['Readiness']._options = None
  _APPPUBLICSERVICE.methods_by_name['Readiness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002,\022\024/v1alpha/__readinessZ\024\022\022/v1alpha/ready/app'
  _APPPUBLICSERVICE.methods_by_name['CreateApp']._options = None
  _APPPUBLICSERVICE.methods_by_name['CreateApp']._serialized_options = b'\222A\005\n\003App\202\323\344\223\002,\"\'/v1alpha/namespaces/{namespace_id}/apps:\001*'
  _APPPUBLICSERVICE.methods_by_name['ListApps']._options = None
  _APPPUBLICSERVICE.methods_by_name['ListApps']._serialized_options = b'\222A\005\n\003App\202\323\344\223\002)\022\'/v1alpha/namespaces/{namespace_id}/apps'
  _APPPUBLICSERVICE.methods_by_name['UpdateApp']._options = None
  _APPPUBLICSERVICE.methods_by_name['UpdateApp']._serialized_options = b'\222A\005\n\003App\202\323\344\223\0025\0320/v1alpha/namespaces/{namespace_id}/apps/{app_id}:\001*'
  _APPPUBLICSERVICE.methods_by_name['DeleteApp']._options = None
  _APPPUBLICSERVICE.methods_by_name['DeleteApp']._serialized_options = b'\222A\005\n\003App\202\323\344\223\0022*0/v1alpha/namespaces/{namespace_id}/apps/{app_id}'
  _APPPUBLICSERVICE.methods_by_name['CreateConversation']._options = None
  _APPPUBLICSERVICE.methods_by_name['CreateConversation']._serialized_options = b'\222A\016\n\014Conversation\202\323\344\223\002C\">/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations:\001*'
  _APPPUBLICSERVICE.methods_by_name['ListConversations']._options = None
  _APPPUBLICSERVICE.methods_by_name['ListConversations']._serialized_options = b'\222A\016\n\014Conversation\202\323\344\223\002@\022>/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations'
  _APPPUBLICSERVICE.methods_by_name['UpdateConversation']._options = None
  _APPPUBLICSERVICE.methods_by_name['UpdateConversation']._serialized_options = b'\222A\016\n\014Conversation\202\323\344\223\002U\032P/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}:\001*'
  _APPPUBLICSERVICE.methods_by_name['DeleteConversation']._options = None
  _APPPUBLICSERVICE.methods_by_name['DeleteConversation']._serialized_options = b'\222A\016\n\014Conversation\202\323\344\223\002R*P/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}'
  _APPPUBLICSERVICE.methods_by_name['CreateMessage']._options = None
  _APPPUBLICSERVICE.methods_by_name['CreateMessage']._serialized_options = b'\222A\t\n\007Message\202\323\344\223\002^\"Y/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}/messages:\001*'
  _APPPUBLICSERVICE.methods_by_name['ListMessages']._options = None
  _APPPUBLICSERVICE.methods_by_name['ListMessages']._serialized_options = b'\222A\t\n\007Message\202\323\344\223\002[\022Y/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}/messages'
  _APPPUBLICSERVICE.methods_by_name['UpdateMessage']._options = None
  _APPPUBLICSERVICE.methods_by_name['UpdateMessage']._serialized_options = b'\222A\t\n\007Message\202\323\344\223\002l\032g/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}/messages/{message_uid}:\001*'
  _APPPUBLICSERVICE.methods_by_name['DeleteMessage']._options = None
  _APPPUBLICSERVICE.methods_by_name['DeleteMessage']._serialized_options = b'\222A\t\n\007Message\202\323\344\223\002i*g/v1alpha/namespaces/{namespace_id}/apps/{app_id}/conversations/{conversation_id}/messages/{message_uid}'
  _APPPUBLICSERVICE.methods_by_name['GetPlaygroundConversation']._options = None
  _APPPUBLICSERVICE.methods_by_name['GetPlaygroundConversation']._serialized_options = b'\222A\014\n\nPlayground\202\323\344\223\002W\022U/v1alpha/namespaces/{namespace_id}/apps/{app_id}/ai_assistant_playground/conversation'
  _APPPUBLICSERVICE.methods_by_name['RestartPlaygroundConversation']._options = None
  _APPPUBLICSERVICE.methods_by_name['RestartPlaygroundConversation']._serialized_options = b'\222A\014\n\nPlayground\202\323\344\223\002R\"P/v1alpha/namespaces/{namespace_id}/apps/{app_id}/ai_assistant_playground/restart'
  _APPPUBLICSERVICE.methods_by_name['Chat']._options = None
  _APPPUBLICSERVICE.methods_by_name['Chat']._serialized_options = b'\222A\005\n\003App\202\323\344\223\002:\"5/v1alpha/namespaces/{namespace_id}/apps/{app_id}/chat:\001*'
  _globals['_APPPUBLICSERVICE']._serialized_start=232
  _globals['_APPPUBLICSERVICE']._serialized_end=3512
# @@protoc_insertion_point(module_scope)
