# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from app.app.v1alpha import app_pb2 as app_dot_app_dot_v1alpha_dot_app__pb2
from app.app.v1alpha import conversation_pb2 as app_dot_app_dot_v1alpha_dot_conversation__pb2


class AppPublicServiceStub(object):
    """AppPublicService exposes the public endpoints that allow clients to
    manage apps.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Liveness = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/Liveness',
                request_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.LivenessRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.LivenessResponse.FromString,
                )
        self.Readiness = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/Readiness',
                request_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.ReadinessRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.ReadinessResponse.FromString,
                )
        self.CreateApp = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/CreateApp',
                request_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.CreateAppRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.CreateAppResponse.FromString,
                )
        self.ListApps = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/ListApps',
                request_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.ListAppsRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.ListAppsResponse.FromString,
                )
        self.UpdateApp = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/UpdateApp',
                request_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.UpdateAppRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.UpdateAppResponse.FromString,
                )
        self.DeleteApp = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/DeleteApp',
                request_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.DeleteAppRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.DeleteAppResponse.FromString,
                )
        self.CreateConversation = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/CreateConversation',
                request_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateConversationRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateConversationResponse.FromString,
                )
        self.ListConversations = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/ListConversations',
                request_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ListConversationsRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ListConversationsResponse.FromString,
                )
        self.UpdateConversation = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/UpdateConversation',
                request_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateConversationRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateConversationResponse.FromString,
                )
        self.DeleteConversation = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/DeleteConversation',
                request_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteConversationRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteConversationResponse.FromString,
                )
        self.CreateMessage = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/CreateMessage',
                request_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateMessageRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateMessageResponse.FromString,
                )
        self.ListMessages = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/ListMessages',
                request_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ListMessagesRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ListMessagesResponse.FromString,
                )
        self.UpdateMessage = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/UpdateMessage',
                request_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateMessageRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateMessageResponse.FromString,
                )
        self.DeleteMessage = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/DeleteMessage',
                request_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteMessageRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteMessageResponse.FromString,
                )
        self.GetPlaygroundConversation = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/GetPlaygroundConversation',
                request_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.GetPlaygroundConversationRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.GetPlaygroundConversationResponse.FromString,
                )
        self.RestartPlaygroundConversation = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/RestartPlaygroundConversation',
                request_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.RestartPlaygroundConversationRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.RestartPlaygroundConversationResponse.FromString,
                )
        self.Chat = channel.unary_unary(
                '/app.app.v1alpha.AppPublicService/Chat',
                request_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ChatRequest.SerializeToString,
                response_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ChatResponse.FromString,
                )


class AppPublicServiceServicer(object):
    """AppPublicService exposes the public endpoints that allow clients to
    manage apps.
    """

    def Liveness(self, request, context):
        """Check if the app server is alive

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Readiness(self, request, context):
        """Check if the app server is ready

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateApp(self, request, context):
        """Create a app
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListApps(self, request, context):
        """List all apps info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateApp(self, request, context):
        """Update a app info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteApp(self, request, context):
        """Delete a app
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateConversation(self, request, context):
        """Create a Conversation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListConversations(self, request, context):
        """List conversations
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateConversation(self, request, context):
        """Update a conversation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteConversation(self, request, context):
        """Delete a conversation
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateMessage(self, request, context):
        """Create a message
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMessages(self, request, context):
        """List messages
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateMessage(self, request, context):
        """Update a message
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteMessage(self, request, context):
        """Delete a message
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPlaygroundConversation(self, request, context):
        """Get Playground Conversation

        get the latest conversation of auth user(e.g. login user and api key user)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RestartPlaygroundConversation(self, request, context):
        """Restart Playground Conversation

        create a new conversation and use the auth user uid as creator uid and auto
        generate a new conversation id on the behalf of auth user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Chat(self, request, context):
        """Chat

        Chat sends a message asynchronously and streams back the response.
        This method is intended for real-time conversation with a chatbot
        and the response needs to be processed incrementally.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AppPublicServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Liveness': grpc.unary_unary_rpc_method_handler(
                    servicer.Liveness,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.LivenessRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.LivenessResponse.SerializeToString,
            ),
            'Readiness': grpc.unary_unary_rpc_method_handler(
                    servicer.Readiness,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.ReadinessRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.ReadinessResponse.SerializeToString,
            ),
            'CreateApp': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateApp,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.CreateAppRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.CreateAppResponse.SerializeToString,
            ),
            'ListApps': grpc.unary_unary_rpc_method_handler(
                    servicer.ListApps,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.ListAppsRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.ListAppsResponse.SerializeToString,
            ),
            'UpdateApp': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateApp,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.UpdateAppRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.UpdateAppResponse.SerializeToString,
            ),
            'DeleteApp': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteApp,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.DeleteAppRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.DeleteAppResponse.SerializeToString,
            ),
            'CreateConversation': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateConversation,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateConversationRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateConversationResponse.SerializeToString,
            ),
            'ListConversations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListConversations,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ListConversationsRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ListConversationsResponse.SerializeToString,
            ),
            'UpdateConversation': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateConversation,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateConversationRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateConversationResponse.SerializeToString,
            ),
            'DeleteConversation': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteConversation,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteConversationRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteConversationResponse.SerializeToString,
            ),
            'CreateMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateMessage,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateMessageRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateMessageResponse.SerializeToString,
            ),
            'ListMessages': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMessages,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ListMessagesRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ListMessagesResponse.SerializeToString,
            ),
            'UpdateMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateMessage,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateMessageRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateMessageResponse.SerializeToString,
            ),
            'DeleteMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteMessage,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteMessageRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteMessageResponse.SerializeToString,
            ),
            'GetPlaygroundConversation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPlaygroundConversation,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.GetPlaygroundConversationRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.GetPlaygroundConversationResponse.SerializeToString,
            ),
            'RestartPlaygroundConversation': grpc.unary_unary_rpc_method_handler(
                    servicer.RestartPlaygroundConversation,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_app__pb2.RestartPlaygroundConversationRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_app__pb2.RestartPlaygroundConversationResponse.SerializeToString,
            ),
            'Chat': grpc.unary_unary_rpc_method_handler(
                    servicer.Chat,
                    request_deserializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ChatRequest.FromString,
                    response_serializer=app_dot_app_dot_v1alpha_dot_conversation__pb2.ChatResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'app.app.v1alpha.AppPublicService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AppPublicService(object):
    """AppPublicService exposes the public endpoints that allow clients to
    manage apps.
    """

    @staticmethod
    def Liveness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/Liveness',
            app_dot_app_dot_v1alpha_dot_app__pb2.LivenessRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_app__pb2.LivenessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Readiness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/Readiness',
            app_dot_app_dot_v1alpha_dot_app__pb2.ReadinessRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_app__pb2.ReadinessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/CreateApp',
            app_dot_app_dot_v1alpha_dot_app__pb2.CreateAppRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_app__pb2.CreateAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListApps(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/ListApps',
            app_dot_app_dot_v1alpha_dot_app__pb2.ListAppsRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_app__pb2.ListAppsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/UpdateApp',
            app_dot_app_dot_v1alpha_dot_app__pb2.UpdateAppRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_app__pb2.UpdateAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteApp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/DeleteApp',
            app_dot_app_dot_v1alpha_dot_app__pb2.DeleteAppRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_app__pb2.DeleteAppResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateConversation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/CreateConversation',
            app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateConversationRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateConversationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListConversations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/ListConversations',
            app_dot_app_dot_v1alpha_dot_conversation__pb2.ListConversationsRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_conversation__pb2.ListConversationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateConversation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/UpdateConversation',
            app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateConversationRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateConversationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteConversation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/DeleteConversation',
            app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteConversationRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteConversationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/CreateMessage',
            app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateMessageRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_conversation__pb2.CreateMessageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListMessages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/ListMessages',
            app_dot_app_dot_v1alpha_dot_conversation__pb2.ListMessagesRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_conversation__pb2.ListMessagesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/UpdateMessage',
            app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateMessageRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_conversation__pb2.UpdateMessageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/DeleteMessage',
            app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteMessageRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_conversation__pb2.DeleteMessageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPlaygroundConversation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/GetPlaygroundConversation',
            app_dot_app_dot_v1alpha_dot_app__pb2.GetPlaygroundConversationRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_app__pb2.GetPlaygroundConversationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RestartPlaygroundConversation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/RestartPlaygroundConversation',
            app_dot_app_dot_v1alpha_dot_app__pb2.RestartPlaygroundConversationRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_app__pb2.RestartPlaygroundConversationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Chat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/app.app.v1alpha.AppPublicService/Chat',
            app_dot_app_dot_v1alpha_dot_conversation__pb2.ChatRequest.SerializeToString,
            app_dot_app_dot_v1alpha_dot_conversation__pb2.ChatResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
