# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/model/v1alpha/model_public_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from model.model.v1alpha import model_pb2 as model_dot_model_dot_v1alpha_dot_model__pb2
from model.model.v1alpha import model_definition_pb2 as model_dot_model_dot_v1alpha_dot_model__definition__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.model/model/v1alpha/model_public_service.proto\x12\x13model.model.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1fmodel/model/v1alpha/model.proto\x1a*model/model/v1alpha/model_definition.proto\x1a.protoc-gen-openapiv2/options/annotations.proto2\xd1k\n\x12ModelPublicService\x12\x9d\x01\n\x08Liveness\x12$.model.model.v1alpha.LivenessRequest\x1a%.model.model.v1alpha.LivenessResponse\"D\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02.\x12\x13/v1alpha/__livenessZ\x17\x12\x15/v1alpha/health/model\x12\xa0\x01\n\tReadiness\x12%.model.model.v1alpha.ReadinessRequest\x1a&.model.model.v1alpha.ReadinessResponse\"D\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02.\x12\x14/v1alpha/__readinessZ\x16\x12\x14/v1alpha/ready/model\x12\xb4\x01\n\x14ListModelDefinitions\x12\x30.model.model.v1alpha.ListModelDefinitionsRequest\x1a\x31.model.model.v1alpha.ListModelDefinitionsResponse\"7\x92\x41\x12\n\x10Model Definition\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1alpha/model-definitions\x12\xaa\x01\n\x14ListAvailableRegions\x12\x30.model.model.v1alpha.ListAvailableRegionsRequest\x1a\x31.model.model.v1alpha.ListAvailableRegionsResponse\"-\x92\x41\x08\n\x06Region\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1alpha/available-regions\x12\xc4\x01\n\x12GetModelDefinition\x12..model.model.v1alpha.GetModelDefinitionRequest\x1a/.model.model.v1alpha.GetModelDefinitionResponse\"M\x92\x41\x12\n\x10Model Definition\x82\xd3\xe4\x93\x02\x32\x12\x30/v1alpha/model-definitions/{model_definition_id}\x12\x80\x01\n\nListModels\x12&.model.model.v1alpha.ListModelsRequest\x1a\'.model.model.v1alpha.ListModelsResponse\"!\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1alpha/models\x12\xa8\x01\n\x0bLookUpModel\x12\'.model.model.v1alpha.LookUpModelRequest\x1a(.model.model.v1alpha.LookUpModelResponse\"F\x92\x41\x07\n\x05Model\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02&\x12$/v1alpha/{permalink=models/*}/lookUp\x12\xb5\x01\n\x13ListNamespaceModels\x12/.model.model.v1alpha.ListNamespaceModelsRequest\x1a\x30.model.model.v1alpha.ListNamespaceModelsResponse\";\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02+\x12)/v1alpha/namespaces/{namespace_id}/models\x12\xbf\x01\n\x14\x43reateNamespaceModel\x12\x30.model.model.v1alpha.CreateNamespaceModelRequest\x1a\x31.model.model.v1alpha.CreateNamespaceModelResponse\"B\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02\x32\")/v1alpha/namespaces/{namespace_id}/models:\x05model\x12\xba\x01\n\x11GetNamespaceModel\x12-.model.model.v1alpha.GetNamespaceModelRequest\x1a..model.model.v1alpha.GetNamespaceModelResponse\"F\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02\x36\x12\x34/v1alpha/namespaces/{namespace_id}/models/{model_id}\x12\xca\x01\n\x14UpdateNamespaceModel\x12\x30.model.model.v1alpha.UpdateNamespaceModelRequest\x1a\x31.model.model.v1alpha.UpdateNamespaceModelResponse\"M\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02=24/v1alpha/namespaces/{namespace_id}/models/{model_id}:\x05model\x12\xc3\x01\n\x14\x44\x65leteNamespaceModel\x12\x30.model.model.v1alpha.DeleteNamespaceModelRequest\x1a\x31.model.model.v1alpha.DeleteNamespaceModelResponse\"F\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02\x36*4/v1alpha/namespaces/{namespace_id}/models/{model_id}\x12\xcd\x01\n\x14RenameNamespaceModel\x12\x30.model.model.v1alpha.RenameNamespaceModelRequest\x1a\x31.model.model.v1alpha.RenameNamespaceModelResponse\"P\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02@\";/v1alpha/namespaces/{namespace_id}/models/{model_id}/rename:\x01*\x12\xdb\x01\n\x13WatchNamespaceModel\x12/.model.model.v1alpha.WatchNamespaceModelRequest\x1a\x30.model.model.v1alpha.WatchNamespaceModelResponse\"a\x92\x41\t\n\x07Version\x82\xd3\xe4\x93\x02O\x12M/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions/{version}/watch\x12\xd8\x01\n\x19WatchNamespaceLatestModel\x12\x35.model.model.v1alpha.WatchNamespaceLatestModelRequest\x1a\x36.model.model.v1alpha.WatchNamespaceLatestModelResponse\"L\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02<\x12:/v1alpha/namespaces/{namespace_id}/models/{model_id}/watch\x12\xe0\x01\n\x1aListNamespaceModelVersions\x12\x36.model.model.v1alpha.ListNamespaceModelVersionsRequest\x1a\x37.model.model.v1alpha.ListNamespaceModelVersionsResponse\"Q\x92\x41\t\n\x07Version\x82\xd3\xe4\x93\x02?\x12=/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions\x12\xed\x01\n\x1b\x44\x65leteNamespaceModelVersion\x12\x37.model.model.v1alpha.DeleteNamespaceModelVersionRequest\x1a\x38.model.model.v1alpha.DeleteNamespaceModelVersionResponse\"[\x92\x41\t\n\x07Version\x82\xd3\xe4\x93\x02I*G/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions/{version}\x12\x8b\x03\n\x15TriggerNamespaceModel\x12\x31.model.model.v1alpha.TriggerNamespaceModelRequest\x1a\x32.model.model.v1alpha.TriggerNamespaceModelResponse\"\x8a\x02\x92\x41\xac\x01\n\x07Triggerr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02T\"O/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions/{version}/trigger:\x01*\x12\xa0\x03\n\x1aTriggerAsyncNamespaceModel\x12\x36.model.model.v1alpha.TriggerAsyncNamespaceModelRequest\x1a\x37.model.model.v1alpha.TriggerAsyncNamespaceModelResponse\"\x90\x02\x92\x41\xac\x01\n\x07Triggerr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02Z\"U/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions/{version}/trigger-async:\x01*\x12\x8a\x03\n\x1bTriggerNamespaceLatestModel\x12\x37.model.model.v1alpha.TriggerNamespaceLatestModelRequest\x1a\x38.model.model.v1alpha.TriggerNamespaceLatestModelResponse\"\xf7\x01\x92\x41\xac\x01\n\x07Triggerr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02\x41\"</v1alpha/namespaces/{namespace_id}/models/{model_id}/trigger:\x01*\x12\x9f\x03\n TriggerAsyncNamespaceLatestModel\x12<.model.model.v1alpha.TriggerAsyncNamespaceLatestModelRequest\x1a=.model.model.v1alpha.TriggerAsyncNamespaceLatestModelResponse\"\xfd\x01\x92\x41\xac\x01\n\x07Triggerr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02G\"B/v1alpha/namespaces/{namespace_id}/models/{model_id}/trigger-async:\x01*\x12\xdd\x02\n%TriggerNamespaceModelBinaryFileUpload\x12\x41.model.model.v1alpha.TriggerNamespaceModelBinaryFileUploadRequest\x1a\x42.model.model.v1alpha.TriggerNamespaceModelBinaryFileUploadResponse\"\xaa\x01\x92\x41\xa6\x01\n\x07Triggerr\x9a\x01\n\x97\x01\n\x15Instill-Requester-Uid\x12|Indicates the authenticated user is making the request on behalf of another entity, typically an organization they belong to\x18\x01(\x01\x12\xef\x02\n+TriggerNamespaceLatestModelBinaryFileUpload\x12G.model.model.v1alpha.TriggerNamespaceLatestModelBinaryFileUploadRequest\x1aH.model.model.v1alpha.TriggerNamespaceLatestModelBinaryFileUploadResponse\"\xaa\x01\x92\x41\xa6\x01\n\x07Triggerr\x9a\x01\n\x97\x01\n\x15Instill-Requester-Uid\x12|Indicates the authenticated user is making the request on behalf of another entity, typically an organization they belong to\x18\x01(\x01\x12\xf2\x01\n\x1aGetNamespaceModelOperation\x12\x36.model.model.v1alpha.GetNamespaceModelOperationRequest\x1a\x37.model.model.v1alpha.GetNamespaceModelOperationResponse\"c\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02S\x12Q/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions/{version}/operation\x12\xf1\x01\n GetNamespaceLatestModelOperation\x12<.model.model.v1alpha.GetNamespaceLatestModelOperationRequest\x1a=.model.model.v1alpha.GetNamespaceLatestModelOperationResponse\"P\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02@\x12>/v1alpha/namespaces/{namespace_id}/models/{model_id}/operation\x12\xa8\x01\n\x11GetModelOperation\x12-.model.model.v1alpha.GetModelOperationRequest\x1a..model.model.v1alpha.GetModelOperationResponse\"4\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02$\x12\"/v1alpha/operations/{operation_id}\x12\xa6\x01\n\x0eListUserModels\x12*.model.model.v1alpha.ListUserModelsRequest\x1a+.model.model.v1alpha.ListUserModelsResponse\";\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\"\x12 /v1alpha/{parent=users/*}/models\x12\xb0\x01\n\x0f\x43reateUserModel\x12+.model.model.v1alpha.CreateUserModelRequest\x1a,.model.model.v1alpha.CreateUserModelResponse\"B\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02)\" /v1alpha/{parent=users/*}/models:\x05model\x12\xa0\x01\n\x0cGetUserModel\x12(.model.model.v1alpha.GetUserModelRequest\x1a).model.model.v1alpha.GetUserModelResponse\";\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\"\x12 /v1alpha/{name=users/*/models/*}\x12\xb6\x01\n\x0fUpdateUserModel\x12+.model.model.v1alpha.UpdateUserModelRequest\x1a,.model.model.v1alpha.UpdateUserModelResponse\"H\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02/2&/v1alpha/{model.name=users/*/models/*}:\x05model\x12\xa9\x01\n\x0f\x44\x65leteUserModel\x12+.model.model.v1alpha.DeleteUserModelRequest\x1a,.model.model.v1alpha.DeleteUserModelResponse\";\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\"* /v1alpha/{name=users/*/models/*}\x12\xb3\x01\n\x0fRenameUserModel\x12+.model.model.v1alpha.RenameUserModelRequest\x1a,.model.model.v1alpha.RenameUserModelResponse\"E\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02,\"\'/v1alpha/{name=users/*/models/*}/rename:\x01*\x12\xc1\x01\n\x0eWatchUserModel\x12*.model.model.v1alpha.WatchUserModelRequest\x1a+.model.model.v1alpha.WatchUserModelResponse\"V\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02=\x12;/v1alpha/{name=users/*/models/*}/versions/{version=*}/watch\x12\xbe\x01\n\x14WatchUserLatestModel\x12\x30.model.model.v1alpha.WatchUserLatestModelRequest\x1a\x31.model.model.v1alpha.WatchUserLatestModelResponse\"A\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02(\x12&/v1alpha/{name=users/*/models/*}/watch\x12\xc4\x01\n\x15ListUserModelVersions\x12\x31.model.model.v1alpha.ListUserModelVersionsRequest\x1a\x32.model.model.v1alpha.ListUserModelVersionsResponse\"D\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02+\x12)/v1alpha/{name=users/*/models/*}/versions\x12\xd3\x01\n\x16\x44\x65leteUserModelVersion\x12\x32.model.model.v1alpha.DeleteUserModelVersionRequest\x1a\x33.model.model.v1alpha.DeleteUserModelVersionResponse\"P\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x37*5/v1alpha/{name=users/*/models/*}/versions/{version=*}\x12\xcc\x01\n\x10TriggerUserModel\x12,.model.model.v1alpha.TriggerUserModelRequest\x1a-.model.model.v1alpha.TriggerUserModelResponse\"[\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x42\"=/v1alpha/{name=users/*/models/*}/versions/{version=*}/trigger:\x01*\x12\xe0\x01\n\x15TriggerAsyncUserModel\x12\x31.model.model.v1alpha.TriggerAsyncUserModelRequest\x1a\x32.model.model.v1alpha.TriggerAsyncUserModelResponse\"`\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02G\"B/v1alpha/{name=users/*/models/*}/versions/{version=*}/triggerAsync:\x01*\x12\xc9\x01\n\x16TriggerUserLatestModel\x12\x32.model.model.v1alpha.TriggerUserLatestModelRequest\x1a\x33.model.model.v1alpha.TriggerUserLatestModelResponse\"F\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02-\"(/v1alpha/{name=users/*/models/*}/trigger:\x01*\x12\xdd\x01\n\x1bTriggerAsyncUserLatestModel\x12\x37.model.model.v1alpha.TriggerAsyncUserLatestModelRequest\x1a\x38.model.model.v1alpha.TriggerAsyncUserLatestModelResponse\"K\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x32\"-/v1alpha/{name=users/*/models/*}/triggerAsync:\x01*\x12\xb6\x01\n TriggerUserModelBinaryFileUpload\x12<.model.model.v1alpha.TriggerUserModelBinaryFileUploadRequest\x1a=.model.model.v1alpha.TriggerUserModelBinaryFileUploadResponse\"\x13\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL(\x01\x12\xc6\x01\n\x16ListOrganizationModels\x12\x32.model.model.v1alpha.ListOrganizationModelsRequest\x1a\x33.model.model.v1alpha.ListOrganizationModelsResponse\"C\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02*\x12(/v1alpha/{parent=organizations/*}/models\x12\xd0\x01\n\x17\x43reateOrganizationModel\x12\x33.model.model.v1alpha.CreateOrganizationModelRequest\x1a\x34.model.model.v1alpha.CreateOrganizationModelResponse\"J\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x31\"(/v1alpha/{parent=organizations/*}/models:\x05model\x12\xc0\x01\n\x14GetOrganizationModel\x12\x30.model.model.v1alpha.GetOrganizationModelRequest\x1a\x31.model.model.v1alpha.GetOrganizationModelResponse\"C\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02*\x12(/v1alpha/{name=organizations/*/models/*}\x12\xd6\x01\n\x17UpdateOrganizationModel\x12\x33.model.model.v1alpha.UpdateOrganizationModelRequest\x1a\x34.model.model.v1alpha.UpdateOrganizationModelResponse\"P\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x37\x32./v1alpha/{model.name=organizations/*/models/*}:\x05model\x12\xc9\x01\n\x17\x44\x65leteOrganizationModel\x12\x33.model.model.v1alpha.DeleteOrganizationModelRequest\x1a\x34.model.model.v1alpha.DeleteOrganizationModelResponse\"C\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02**(/v1alpha/{name=organizations/*/models/*}\x12\xd3\x01\n\x17RenameOrganizationModel\x12\x33.model.model.v1alpha.RenameOrganizationModelRequest\x1a\x34.model.model.v1alpha.RenameOrganizationModelResponse\"M\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x34\"//v1alpha/{name=organizations/*/models/*}/rename:\x01*\x12\xe1\x01\n\x16WatchOrganizationModel\x12\x32.model.model.v1alpha.WatchOrganizationModelRequest\x1a\x33.model.model.v1alpha.WatchOrganizationModelResponse\"^\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x45\x12\x43/v1alpha/{name=organizations/*/models/*}/versions/{version=*}/watch\x12\xde\x01\n\x1cWatchOrganizationLatestModel\x12\x38.model.model.v1alpha.WatchOrganizationLatestModelRequest\x1a\x39.model.model.v1alpha.WatchOrganizationLatestModelResponse\"I\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x30\x12./v1alpha/{name=organizations/*/models/*}/watch\x12\xe4\x01\n\x1dListOrganizationModelVersions\x12\x39.model.model.v1alpha.ListOrganizationModelVersionsRequest\x1a:.model.model.v1alpha.ListOrganizationModelVersionsResponse\"L\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x33\x12\x31/v1alpha/{name=organizations/*/models/*}/versions\x12\xf3\x01\n\x1e\x44\x65leteOrganizationModelVersion\x12:.model.model.v1alpha.DeleteOrganizationModelVersionRequest\x1a;.model.model.v1alpha.DeleteOrganizationModelVersionResponse\"X\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02?*=/v1alpha/{name=organizations/*/models/*}/versions/{version=*}\x12\xec\x01\n\x18TriggerOrganizationModel\x12\x34.model.model.v1alpha.TriggerOrganizationModelRequest\x1a\x35.model.model.v1alpha.TriggerOrganizationModelResponse\"c\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02J\"E/v1alpha/{name=organizations/*/models/*}/versions/{version=*}/trigger:\x01*\x12\x80\x02\n\x1dTriggerAsyncOrganizationModel\x12\x39.model.model.v1alpha.TriggerAsyncOrganizationModelRequest\x1a:.model.model.v1alpha.TriggerAsyncOrganizationModelResponse\"h\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02O\"J/v1alpha/{name=organizations/*/models/*}/versions/{version=*}/triggerAsync:\x01*\x12\xe9\x01\n\x1eTriggerOrganizationLatestModel\x12:.model.model.v1alpha.TriggerOrganizationLatestModelRequest\x1a;.model.model.v1alpha.TriggerOrganizationLatestModelResponse\"N\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x35\"0/v1alpha/{name=organizations/*/models/*}/trigger:\x01*\x12\xfd\x01\n#TriggerAsyncOrganizationLatestModel\x12?.model.model.v1alpha.TriggerAsyncOrganizationLatestModelRequest\x1a@.model.model.v1alpha.TriggerAsyncOrganizationLatestModelResponse\"S\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02:\"5/v1alpha/{name=organizations/*/models/*}/triggerAsync:\x01*\x12\xce\x01\n(TriggerOrganizationModelBinaryFileUpload\x12\x44.model.model.v1alpha.TriggerOrganizationModelBinaryFileUploadRequest\x1a\x45.model.model.v1alpha.TriggerOrganizationModelBinaryFileUploadResponse\"\x13\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL(\x01\x12\xd7\x01\n\x1bGetUserLatestModelOperation\x12\x37.model.model.v1alpha.GetUserLatestModelOperationRequest\x1a\x38.model.model.v1alpha.GetUserLatestModelOperationResponse\"E\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02,\x12*/v1alpha/{name=users/*/models/*}/operation\x12\xf7\x01\n#GetOrganizationLatestModelOperation\x12?.model.model.v1alpha.GetOrganizationLatestModelOperationRequest\x1a@.model.model.v1alpha.GetOrganizationLatestModelOperationResponse\"M\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x34\x12\x32/v1alpha/{name=organizations/*/models/*}/operation\x12\xda\x02\n\rListModelRuns\x12).model.model.v1alpha.ListModelRunsRequest\x1a*.model.model.v1alpha.ListModelRunsResponse\"\xf1\x01\x92\x41\xac\x01\n\x07Triggerr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02;\x12\x39/v1alpha/namespaces/{namespace_id}/models/{model_id}/runs\x12\xe6\x02\n\x1aListModelRunsByCreditOwner\x12\x36.model.model.v1alpha.ListModelRunsByCreditOwnerRequest\x1a\x37.model.model.v1alpha.ListModelRunsByCreditOwnerResponse\"\xd6\x01\x92\x41\xac\x01\n\x07Triggerr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02 \x12\x1e/v1alpha/dashboard/models/runs\x1a\x1b\x92\x41\x18\x12\x16Public Model endpointsB\xe4\x01\n\x17\x63om.model.model.v1alphaB\x17ModelPublicServiceProtoP\x01ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\xa2\x02\x03MMX\xaa\x02\x13Model.Model.V1alpha\xca\x02\x13Model\\Model\\V1alpha\xe2\x02\x1fModel\\Model\\V1alpha\\GPBMetadata\xea\x02\x15Model::Model::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.model.v1alpha.model_public_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.model.model.v1alphaB\027ModelPublicServiceProtoP\001ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\242\002\003MMX\252\002\023Model.Model.V1alpha\312\002\023Model\\Model\\V1alpha\342\002\037Model\\Model\\V1alpha\\GPBMetadata\352\002\025Model::Model::V1alpha'
  _MODELPUBLICSERVICE._options = None
  _MODELPUBLICSERVICE._serialized_options = b'\222A\030\022\026Public Model endpoints'
  _MODELPUBLICSERVICE.methods_by_name['Liveness']._options = None
  _MODELPUBLICSERVICE.methods_by_name['Liveness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002.\022\023/v1alpha/__livenessZ\027\022\025/v1alpha/health/model'
  _MODELPUBLICSERVICE.methods_by_name['Readiness']._options = None
  _MODELPUBLICSERVICE.methods_by_name['Readiness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002.\022\024/v1alpha/__readinessZ\026\022\024/v1alpha/ready/model'
  _MODELPUBLICSERVICE.methods_by_name['ListModelDefinitions']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListModelDefinitions']._serialized_options = b'\222A\022\n\020Model Definition\202\323\344\223\002\034\022\032/v1alpha/model-definitions'
  _MODELPUBLICSERVICE.methods_by_name['ListAvailableRegions']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListAvailableRegions']._serialized_options = b'\222A\010\n\006Region\202\323\344\223\002\034\022\032/v1alpha/available-regions'
  _MODELPUBLICSERVICE.methods_by_name['GetModelDefinition']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetModelDefinition']._serialized_options = b'\222A\022\n\020Model Definition\202\323\344\223\0022\0220/v1alpha/model-definitions/{model_definition_id}'
  _MODELPUBLICSERVICE.methods_by_name['ListModels']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListModels']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\002\021\022\017/v1alpha/models'
  _MODELPUBLICSERVICE.methods_by_name['LookUpModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['LookUpModel']._serialized_options = b'\222A\007\n\005Model\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002&\022$/v1alpha/{permalink=models/*}/lookUp'
  _MODELPUBLICSERVICE.methods_by_name['ListNamespaceModels']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListNamespaceModels']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\002+\022)/v1alpha/namespaces/{namespace_id}/models'
  _MODELPUBLICSERVICE.methods_by_name['CreateNamespaceModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['CreateNamespaceModel']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\0022\")/v1alpha/namespaces/{namespace_id}/models:\005model'
  _MODELPUBLICSERVICE.methods_by_name['GetNamespaceModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetNamespaceModel']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\0026\0224/v1alpha/namespaces/{namespace_id}/models/{model_id}'
  _MODELPUBLICSERVICE.methods_by_name['UpdateNamespaceModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['UpdateNamespaceModel']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\002=24/v1alpha/namespaces/{namespace_id}/models/{model_id}:\005model'
  _MODELPUBLICSERVICE.methods_by_name['DeleteNamespaceModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['DeleteNamespaceModel']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\0026*4/v1alpha/namespaces/{namespace_id}/models/{model_id}'
  _MODELPUBLICSERVICE.methods_by_name['RenameNamespaceModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['RenameNamespaceModel']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\002@\";/v1alpha/namespaces/{namespace_id}/models/{model_id}/rename:\001*'
  _MODELPUBLICSERVICE.methods_by_name['WatchNamespaceModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['WatchNamespaceModel']._serialized_options = b'\222A\t\n\007Version\202\323\344\223\002O\022M/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions/{version}/watch'
  _MODELPUBLICSERVICE.methods_by_name['WatchNamespaceLatestModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['WatchNamespaceLatestModel']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\002<\022:/v1alpha/namespaces/{namespace_id}/models/{model_id}/watch'
  _MODELPUBLICSERVICE.methods_by_name['ListNamespaceModelVersions']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListNamespaceModelVersions']._serialized_options = b'\222A\t\n\007Version\202\323\344\223\002?\022=/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions'
  _MODELPUBLICSERVICE.methods_by_name['DeleteNamespaceModelVersion']._options = None
  _MODELPUBLICSERVICE.methods_by_name['DeleteNamespaceModelVersion']._serialized_options = b'\222A\t\n\007Version\202\323\344\223\002I*G/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions/{version}'
  _MODELPUBLICSERVICE.methods_by_name['TriggerNamespaceModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerNamespaceModel']._serialized_options = b'\222A\254\001\n\007Triggerr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002T\"O/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions/{version}/trigger:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncNamespaceModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncNamespaceModel']._serialized_options = b'\222A\254\001\n\007Triggerr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002Z\"U/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions/{version}/trigger-async:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerNamespaceLatestModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerNamespaceLatestModel']._serialized_options = b'\222A\254\001\n\007Triggerr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002A\"</v1alpha/namespaces/{namespace_id}/models/{model_id}/trigger:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncNamespaceLatestModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncNamespaceLatestModel']._serialized_options = b'\222A\254\001\n\007Triggerr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002G\"B/v1alpha/namespaces/{namespace_id}/models/{model_id}/trigger-async:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerNamespaceModelBinaryFileUpload']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerNamespaceModelBinaryFileUpload']._serialized_options = b'\222A\246\001\n\007Triggerr\232\001\n\227\001\n\025Instill-Requester-Uid\022|Indicates the authenticated user is making the request on behalf of another entity, typically an organization they belong to\030\001'
  _MODELPUBLICSERVICE.methods_by_name['TriggerNamespaceLatestModelBinaryFileUpload']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerNamespaceLatestModelBinaryFileUpload']._serialized_options = b'\222A\246\001\n\007Triggerr\232\001\n\227\001\n\025Instill-Requester-Uid\022|Indicates the authenticated user is making the request on behalf of another entity, typically an organization they belong to\030\001'
  _MODELPUBLICSERVICE.methods_by_name['GetNamespaceModelOperation']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetNamespaceModelOperation']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\002S\022Q/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions/{version}/operation'
  _MODELPUBLICSERVICE.methods_by_name['GetNamespaceLatestModelOperation']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetNamespaceLatestModelOperation']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\002@\022>/v1alpha/namespaces/{namespace_id}/models/{model_id}/operation'
  _MODELPUBLICSERVICE.methods_by_name['GetModelOperation']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetModelOperation']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\002$\022\"/v1alpha/operations/{operation_id}'
  _MODELPUBLICSERVICE.methods_by_name['ListUserModels']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListUserModels']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\"\022 /v1alpha/{parent=users/*}/models'
  _MODELPUBLICSERVICE.methods_by_name['CreateUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['CreateUserModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002)\" /v1alpha/{parent=users/*}/models:\005model'
  _MODELPUBLICSERVICE.methods_by_name['GetUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetUserModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\"\022 /v1alpha/{name=users/*/models/*}'
  _MODELPUBLICSERVICE.methods_by_name['UpdateUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['UpdateUserModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002/2&/v1alpha/{model.name=users/*/models/*}:\005model'
  _MODELPUBLICSERVICE.methods_by_name['DeleteUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['DeleteUserModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\"* /v1alpha/{name=users/*/models/*}'
  _MODELPUBLICSERVICE.methods_by_name['RenameUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['RenameUserModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002,\"\'/v1alpha/{name=users/*/models/*}/rename:\001*'
  _MODELPUBLICSERVICE.methods_by_name['WatchUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['WatchUserModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002=\022;/v1alpha/{name=users/*/models/*}/versions/{version=*}/watch'
  _MODELPUBLICSERVICE.methods_by_name['WatchUserLatestModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['WatchUserLatestModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002(\022&/v1alpha/{name=users/*/models/*}/watch'
  _MODELPUBLICSERVICE.methods_by_name['ListUserModelVersions']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListUserModelVersions']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002+\022)/v1alpha/{name=users/*/models/*}/versions'
  _MODELPUBLICSERVICE.methods_by_name['DeleteUserModelVersion']._options = None
  _MODELPUBLICSERVICE.methods_by_name['DeleteUserModelVersion']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0027*5/v1alpha/{name=users/*/models/*}/versions/{version=*}'
  _MODELPUBLICSERVICE.methods_by_name['TriggerUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerUserModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002B\"=/v1alpha/{name=users/*/models/*}/versions/{version=*}/trigger:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncUserModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002G\"B/v1alpha/{name=users/*/models/*}/versions/{version=*}/triggerAsync:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerUserLatestModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerUserLatestModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002-\"(/v1alpha/{name=users/*/models/*}/trigger:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncUserLatestModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncUserLatestModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0022\"-/v1alpha/{name=users/*/models/*}/triggerAsync:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerUserModelBinaryFileUpload']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerUserModelBinaryFileUpload']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL'
  _MODELPUBLICSERVICE.methods_by_name['ListOrganizationModels']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListOrganizationModels']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002*\022(/v1alpha/{parent=organizations/*}/models'
  _MODELPUBLICSERVICE.methods_by_name['CreateOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['CreateOrganizationModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0021\"(/v1alpha/{parent=organizations/*}/models:\005model'
  _MODELPUBLICSERVICE.methods_by_name['GetOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetOrganizationModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002*\022(/v1alpha/{name=organizations/*/models/*}'
  _MODELPUBLICSERVICE.methods_by_name['UpdateOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['UpdateOrganizationModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\00272./v1alpha/{model.name=organizations/*/models/*}:\005model'
  _MODELPUBLICSERVICE.methods_by_name['DeleteOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['DeleteOrganizationModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002**(/v1alpha/{name=organizations/*/models/*}'
  _MODELPUBLICSERVICE.methods_by_name['RenameOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['RenameOrganizationModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0024\"//v1alpha/{name=organizations/*/models/*}/rename:\001*'
  _MODELPUBLICSERVICE.methods_by_name['WatchOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['WatchOrganizationModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002E\022C/v1alpha/{name=organizations/*/models/*}/versions/{version=*}/watch'
  _MODELPUBLICSERVICE.methods_by_name['WatchOrganizationLatestModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['WatchOrganizationLatestModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0020\022./v1alpha/{name=organizations/*/models/*}/watch'
  _MODELPUBLICSERVICE.methods_by_name['ListOrganizationModelVersions']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListOrganizationModelVersions']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0023\0221/v1alpha/{name=organizations/*/models/*}/versions'
  _MODELPUBLICSERVICE.methods_by_name['DeleteOrganizationModelVersion']._options = None
  _MODELPUBLICSERVICE.methods_by_name['DeleteOrganizationModelVersion']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002?*=/v1alpha/{name=organizations/*/models/*}/versions/{version=*}'
  _MODELPUBLICSERVICE.methods_by_name['TriggerOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerOrganizationModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002J\"E/v1alpha/{name=organizations/*/models/*}/versions/{version=*}/trigger:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncOrganizationModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002O\"J/v1alpha/{name=organizations/*/models/*}/versions/{version=*}/triggerAsync:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerOrganizationLatestModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerOrganizationLatestModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0025\"0/v1alpha/{name=organizations/*/models/*}/trigger:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncOrganizationLatestModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncOrganizationLatestModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002:\"5/v1alpha/{name=organizations/*/models/*}/triggerAsync:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerOrganizationModelBinaryFileUpload']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerOrganizationModelBinaryFileUpload']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL'
  _MODELPUBLICSERVICE.methods_by_name['GetUserLatestModelOperation']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetUserLatestModelOperation']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002,\022*/v1alpha/{name=users/*/models/*}/operation'
  _MODELPUBLICSERVICE.methods_by_name['GetOrganizationLatestModelOperation']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetOrganizationLatestModelOperation']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0024\0222/v1alpha/{name=organizations/*/models/*}/operation'
  _MODELPUBLICSERVICE.methods_by_name['ListModelRuns']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListModelRuns']._serialized_options = b'\222A\254\001\n\007Triggerr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002;\0229/v1alpha/namespaces/{namespace_id}/models/{model_id}/runs'
  _MODELPUBLICSERVICE.methods_by_name['ListModelRunsByCreditOwner']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListModelRunsByCreditOwner']._serialized_options = b'\222A\254\001\n\007Triggerr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002 \022\036/v1alpha/dashboard/models/runs'
  _globals['_MODELPUBLICSERVICE']._serialized_start=256
  _globals['_MODELPUBLICSERVICE']._serialized_end=14033
# @@protoc_insertion_point(module_scope)
