# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from core.mgmt.v1beta import metric_pb2 as core_dot_mgmt_dot_v1beta_dot_metric__pb2
from core.mgmt.v1beta import mgmt_pb2 as core_dot_mgmt_dot_v1beta_dot_mgmt__pb2


class MgmtPublicServiceStub(object):
    """MGMT

    MgmtPublicService exposes the public Core endpoints that allow clients to
    manage user resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Liveness = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/Liveness',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LivenessRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LivenessResponse.FromString,
                )
        self.Readiness = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/Readiness',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ReadinessRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ReadinessResponse.FromString,
                )
        self.GetAuthenticatedUser = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/GetAuthenticatedUser',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserResponse.FromString,
                )
        self.PatchAuthenticatedUser = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/PatchAuthenticatedUser',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.PatchAuthenticatedUserRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.PatchAuthenticatedUserResponse.FromString,
                )
        self.ListUsers = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/ListUsers',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersResponse.FromString,
                )
        self.GetUser = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/GetUser',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserResponse.FromString,
                )
        self.CreateOrganization = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/CreateOrganization',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateOrganizationRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateOrganizationResponse.FromString,
                )
        self.ListOrganizations = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/ListOrganizations',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsResponse.FromString,
                )
        self.GetOrganization = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/GetOrganization',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationResponse.FromString,
                )
        self.UpdateOrganization = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/UpdateOrganization',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationResponse.FromString,
                )
        self.DeleteOrganization = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/DeleteOrganization',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationResponse.FromString,
                )
        self.ListUserMemberships = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/ListUserMemberships',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUserMembershipsRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUserMembershipsResponse.FromString,
                )
        self.GetUserMembership = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/GetUserMembership',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserMembershipRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserMembershipResponse.FromString,
                )
        self.UpdateUserMembership = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/UpdateUserMembership',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateUserMembershipRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateUserMembershipResponse.FromString,
                )
        self.DeleteUserMembership = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/DeleteUserMembership',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteUserMembershipRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteUserMembershipResponse.FromString,
                )
        self.ListOrganizationMemberships = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/ListOrganizationMemberships',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationMembershipsRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationMembershipsResponse.FromString,
                )
        self.GetOrganizationMembership = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/GetOrganizationMembership',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationMembershipRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationMembershipResponse.FromString,
                )
        self.UpdateOrganizationMembership = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/UpdateOrganizationMembership',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationMembershipRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationMembershipResponse.FromString,
                )
        self.DeleteOrganizationMembership = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/DeleteOrganizationMembership',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationMembershipRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationMembershipResponse.FromString,
                )
        self.GetAuthenticatedUserSubscription = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/GetAuthenticatedUserSubscription',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserSubscriptionRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserSubscriptionResponse.FromString,
                )
        self.GetOrganizationSubscription = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/GetOrganizationSubscription',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionResponse.FromString,
                )
        self.CreateToken = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/CreateToken',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateTokenRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateTokenResponse.FromString,
                )
        self.ListTokens = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/ListTokens',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListTokensRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListTokensResponse.FromString,
                )
        self.GetToken = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/GetToken',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetTokenRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetTokenResponse.FromString,
                )
        self.DeleteToken = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/DeleteToken',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteTokenRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteTokenResponse.FromString,
                )
        self.ValidateToken = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/ValidateToken',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ValidateTokenRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ValidateTokenResponse.FromString,
                )
        self.GetRemainingCredit = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/GetRemainingCredit',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetRemainingCreditRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetRemainingCreditResponse.FromString,
                )
        self.CheckNamespace = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/CheckNamespace',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceResponse.FromString,
                )
        self.GetPipelineTriggerCount = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/GetPipelineTriggerCount',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.GetPipelineTriggerCountRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.GetPipelineTriggerCountResponse.FromString,
                )
        self.ListPipelineTriggerTableRecords = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/ListPipelineTriggerTableRecords',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerTableRecordsRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerTableRecordsResponse.FromString,
                )
        self.ListPipelineTriggerChartRecords = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/ListPipelineTriggerChartRecords',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerChartRecordsRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerChartRecordsResponse.FromString,
                )
        self.ListCreditConsumptionChartRecords = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/ListCreditConsumptionChartRecords',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListCreditConsumptionChartRecordsRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListCreditConsumptionChartRecordsResponse.FromString,
                )
        self.AuthTokenIssuer = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/AuthTokenIssuer',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthTokenIssuerRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthTokenIssuerResponse.FromString,
                )
        self.AuthLogin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/AuthLogin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLoginRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLoginResponse.FromString,
                )
        self.AuthLogout = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/AuthLogout',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLogoutRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLogoutResponse.FromString,
                )
        self.AuthChangePassword = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/AuthChangePassword',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthChangePasswordRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthChangePasswordResponse.FromString,
                )
        self.AuthValidateAccessToken = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/AuthValidateAccessToken',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthValidateAccessTokenRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthValidateAccessTokenResponse.FromString,
                )


class MgmtPublicServiceServicer(object):
    """MGMT

    MgmtPublicService exposes the public Core endpoints that allow clients to
    manage user resources.
    """

    def Liveness(self, request, context):
        """Check if the MGMT server is alive

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Readiness(self, request, context):
        """Check if the pipeline server is ready

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAuthenticatedUser(self, request, context):
        """Get the authenticated user

        Returns the details of the authenticated user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PatchAuthenticatedUser(self, request, context):
        """Update the authenticated user

        Updates the information of the authenticated user.

        In REST requests, only the supplied user fields will be taken into account
        when updating the resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUsers(self, request, context):
        """List users

        Returns a paginated list of users.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUser(self, request, context):
        """Get a user

        Returns the details of a user by their ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOrganization(self, request, context):
        """Create an organization

        Creates an organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizations(self, request, context):
        """List organizations

        Returns a paginated list of organizations.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganization(self, request, context):
        """Get an organization

        Returns the organization details by its ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOrganization(self, request, context):
        """Update an organization

        Accesses and updates an organization by ID.

        In REST requests, only the supplied organization fields will be taken into
        account when updating the resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganization(self, request, context):
        """Delete an organization

        Accesses and deletes an organization by ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserMemberships(self, request, context):
        """List user memberships

        Returns the memberships of a user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserMembership(self, request, context):
        """Get a user membership

        Returns the details of the relationship between a user and an
        organization. The authenticated must match the membership parent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserMembership(self, request, context):
        """Update a user membership

        Accesses and updates a user membership by parent and membership IDs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUserMembership(self, request, context):
        """Delete a user membership

        Accesses and deletes a user membership by parent and membership IDs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizationMemberships(self, request, context):
        """List organization memberships

        Returns a paginated list of the user memberships in an organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationMembership(self, request, context):
        """Get a an organization membership

        Returns the details of a user membership within an organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOrganizationMembership(self, request, context):
        """Uppdate an organization membership

        Updates a user membership within an organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganizationMembership(self, request, context):
        """Delete an organization membership

        Deletes a user membership within an organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAuthenticatedUserSubscription(self, request, context):
        """Get the subscription of the authenticated user

        Returns the subscription details of the authenticated user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationSubscription(self, request, context):
        """Get the subscription of an organization

        Returns the subscription details of an organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateToken(self, request, context):
        """Create an API token

        Creates an API token for the authenticated user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTokens(self, request, context):
        """List API tokens

        Returns a paginated list of the API tokens of the authenticated user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetToken(self, request, context):
        """Get an API token

        Returns the details of an API token.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteToken(self, request, context):
        """Delete an API token

        Deletes an API token.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateToken(self, request, context):
        """Validate an API token

        Validates an API token.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRemainingCredit(self, request, context):
        """Get the remaining Instill Credit

        This endpoint returns the remaining [Instill Credit](https://www.instill.tech/docs/vdp/credit) of a given user or
        organization. The requested credit owner must be either the authenticated
        user or an organization they belong to.

        On Instill Core, this endpoint will return a 404 Not Found status.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckNamespace(self, request, context):
        """Check if a namespace is in use

        Returns the availability of a namespace or, alternatively, the type of
        resource that is using it.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPipelineTriggerCount(self, request, context):
        """Get pipeline trigger count

        Returns the pipeline trigger count of a given requester within a timespan.
        Results are grouped by trigger status.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPipelineTriggerTableRecords(self, request, context):
        """List pipeline trigger metrics

        Returns a paginated list of pipeline executions aggregated by pipeline ID.
        NOTE: This method is deprecated and will be retired soon.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPipelineTriggerChartRecords(self, request, context):
        """List pipeline trigger time charts

        Returns a timeline of pipline trigger counts for the pipelines of a given
        owner.
        NOTE: This method will soon return the trigger counts of a given requester.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListCreditConsumptionChartRecords(self, request, context):
        """List Instill Credit consumption time charts

        Returns a timeline of Instill Credit consumption for a given owner. The
        response will contain one set of records (datapoints) per consumption
        source (e.g. "pipeline", "model"). Each datapoint represents the amount
        consumed in a time bucket.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AuthTokenIssuer(self, request, context):
        """Auth endpoints are only used in the community edition and the OpenAPI
        documentation references Instill Cloud. Therefore, these endpoints are
        hidden.

        Get Auth token issuer

        Returns the auth token issuer details. This operation requires admin permissions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AuthLogin(self, request, context):
        """Log in a user

        Authenticates a user and returns an access token.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AuthLogout(self, request, context):
        """Log out a user

        Logs out an authenticated user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AuthChangePassword(self, request, context):
        """Change password

        Updates the password of a user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AuthValidateAccessToken(self, request, context):
        """Validate an access token

        Checks the validity of an access token.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MgmtPublicServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Liveness': grpc.unary_unary_rpc_method_handler(
                    servicer.Liveness,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LivenessRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LivenessResponse.SerializeToString,
            ),
            'Readiness': grpc.unary_unary_rpc_method_handler(
                    servicer.Readiness,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ReadinessRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ReadinessResponse.SerializeToString,
            ),
            'GetAuthenticatedUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAuthenticatedUser,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserResponse.SerializeToString,
            ),
            'PatchAuthenticatedUser': grpc.unary_unary_rpc_method_handler(
                    servicer.PatchAuthenticatedUser,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.PatchAuthenticatedUserRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.PatchAuthenticatedUserResponse.SerializeToString,
            ),
            'ListUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUsers,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersResponse.SerializeToString,
            ),
            'GetUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUser,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserResponse.SerializeToString,
            ),
            'CreateOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrganization,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateOrganizationRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateOrganizationResponse.SerializeToString,
            ),
            'ListOrganizations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizations,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsResponse.SerializeToString,
            ),
            'GetOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganization,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationResponse.SerializeToString,
            ),
            'UpdateOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOrganization,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationResponse.SerializeToString,
            ),
            'DeleteOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganization,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationResponse.SerializeToString,
            ),
            'ListUserMemberships': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserMemberships,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUserMembershipsRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUserMembershipsResponse.SerializeToString,
            ),
            'GetUserMembership': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserMembership,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserMembershipRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserMembershipResponse.SerializeToString,
            ),
            'UpdateUserMembership': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserMembership,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateUserMembershipRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateUserMembershipResponse.SerializeToString,
            ),
            'DeleteUserMembership': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUserMembership,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteUserMembershipRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteUserMembershipResponse.SerializeToString,
            ),
            'ListOrganizationMemberships': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizationMemberships,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationMembershipsRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationMembershipsResponse.SerializeToString,
            ),
            'GetOrganizationMembership': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationMembership,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationMembershipRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationMembershipResponse.SerializeToString,
            ),
            'UpdateOrganizationMembership': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOrganizationMembership,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationMembershipRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationMembershipResponse.SerializeToString,
            ),
            'DeleteOrganizationMembership': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganizationMembership,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationMembershipRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationMembershipResponse.SerializeToString,
            ),
            'GetAuthenticatedUserSubscription': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAuthenticatedUserSubscription,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserSubscriptionRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserSubscriptionResponse.SerializeToString,
            ),
            'GetOrganizationSubscription': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationSubscription,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionResponse.SerializeToString,
            ),
            'CreateToken': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateToken,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateTokenRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateTokenResponse.SerializeToString,
            ),
            'ListTokens': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTokens,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListTokensRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListTokensResponse.SerializeToString,
            ),
            'GetToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GetToken,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetTokenRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetTokenResponse.SerializeToString,
            ),
            'DeleteToken': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteToken,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteTokenRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteTokenResponse.SerializeToString,
            ),
            'ValidateToken': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateToken,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ValidateTokenRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ValidateTokenResponse.SerializeToString,
            ),
            'GetRemainingCredit': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRemainingCredit,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetRemainingCreditRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetRemainingCreditResponse.SerializeToString,
            ),
            'CheckNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckNamespace,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceResponse.SerializeToString,
            ),
            'GetPipelineTriggerCount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPipelineTriggerCount,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.GetPipelineTriggerCountRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.GetPipelineTriggerCountResponse.SerializeToString,
            ),
            'ListPipelineTriggerTableRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPipelineTriggerTableRecords,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerTableRecordsRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerTableRecordsResponse.SerializeToString,
            ),
            'ListPipelineTriggerChartRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPipelineTriggerChartRecords,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerChartRecordsRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerChartRecordsResponse.SerializeToString,
            ),
            'ListCreditConsumptionChartRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCreditConsumptionChartRecords,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListCreditConsumptionChartRecordsRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListCreditConsumptionChartRecordsResponse.SerializeToString,
            ),
            'AuthTokenIssuer': grpc.unary_unary_rpc_method_handler(
                    servicer.AuthTokenIssuer,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthTokenIssuerRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthTokenIssuerResponse.SerializeToString,
            ),
            'AuthLogin': grpc.unary_unary_rpc_method_handler(
                    servicer.AuthLogin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLoginRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLoginResponse.SerializeToString,
            ),
            'AuthLogout': grpc.unary_unary_rpc_method_handler(
                    servicer.AuthLogout,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLogoutRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLogoutResponse.SerializeToString,
            ),
            'AuthChangePassword': grpc.unary_unary_rpc_method_handler(
                    servicer.AuthChangePassword,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthChangePasswordRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthChangePasswordResponse.SerializeToString,
            ),
            'AuthValidateAccessToken': grpc.unary_unary_rpc_method_handler(
                    servicer.AuthValidateAccessToken,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthValidateAccessTokenRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthValidateAccessTokenResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'core.mgmt.v1beta.MgmtPublicService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MgmtPublicService(object):
    """MGMT

    MgmtPublicService exposes the public Core endpoints that allow clients to
    manage user resources.
    """

    @staticmethod
    def Liveness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/Liveness',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LivenessRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LivenessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Readiness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/Readiness',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ReadinessRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ReadinessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAuthenticatedUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/GetAuthenticatedUser',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PatchAuthenticatedUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/PatchAuthenticatedUser',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.PatchAuthenticatedUserRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.PatchAuthenticatedUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/ListUsers',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/GetUser',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/CreateOrganization',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateOrganizationRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateOrganizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/ListOrganizations',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/GetOrganization',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/UpdateOrganization',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/DeleteOrganization',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserMemberships(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/ListUserMemberships',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUserMembershipsRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUserMembershipsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserMembership(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/GetUserMembership',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserMembershipRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserMembershipResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserMembership(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/UpdateUserMembership',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateUserMembershipRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateUserMembershipResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteUserMembership(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/DeleteUserMembership',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteUserMembershipRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteUserMembershipResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizationMemberships(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/ListOrganizationMemberships',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationMembershipsRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationMembershipsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationMembership(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/GetOrganizationMembership',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationMembershipRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationMembershipResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOrganizationMembership(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/UpdateOrganizationMembership',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationMembershipRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationMembershipResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganizationMembership(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/DeleteOrganizationMembership',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationMembershipRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationMembershipResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAuthenticatedUserSubscription(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/GetAuthenticatedUserSubscription',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserSubscriptionRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserSubscriptionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationSubscription(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/GetOrganizationSubscription',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/CreateToken',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateTokenRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTokens(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/ListTokens',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListTokensRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListTokensResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/GetToken',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetTokenRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/DeleteToken',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteTokenRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/ValidateToken',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ValidateTokenRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ValidateTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRemainingCredit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/GetRemainingCredit',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetRemainingCreditRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetRemainingCreditResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/CheckNamespace',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPipelineTriggerCount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/GetPipelineTriggerCount',
            core_dot_mgmt_dot_v1beta_dot_metric__pb2.GetPipelineTriggerCountRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_metric__pb2.GetPipelineTriggerCountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPipelineTriggerTableRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/ListPipelineTriggerTableRecords',
            core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerTableRecordsRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerTableRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPipelineTriggerChartRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/ListPipelineTriggerChartRecords',
            core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerChartRecordsRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerChartRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListCreditConsumptionChartRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/ListCreditConsumptionChartRecords',
            core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListCreditConsumptionChartRecordsRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListCreditConsumptionChartRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AuthTokenIssuer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/AuthTokenIssuer',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthTokenIssuerRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthTokenIssuerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AuthLogin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/AuthLogin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLoginRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLoginResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AuthLogout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/AuthLogout',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLogoutRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLogoutResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AuthChangePassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/AuthChangePassword',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthChangePasswordRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthChangePasswordResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AuthValidateAccessToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/AuthValidateAccessToken',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthValidateAccessTokenRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthValidateAccessTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
